@@ -4,6 +4,9 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.util.Arrays;
 import java.util.logging.Level;
+import java.util.logging.Logger;
+import uk.ac.starlink.auth.AuthManager;
+import uk.ac.starlink.auth.UserInterface;
 import uk.ac.starlink.table.StarTableFactory;
 import uk.ac.starlink.table.TableScheme;
 import uk.ac.starlink.task.Task;
@@ -16,7 +19,6 @@ import uk.ac.starlink.util.IOUtils;
 import uk.ac.starlink.util.Loader;
 import uk.ac.starlink.util.ObjectFactory;
 import uk.ac.starlink.util.Pair;
-import uk.ac.starlink.util.PropertyAuthenticator;
 import uk.ac.starlink.util.URLUtils;
 
 /**
@@ -32,6 +34,8 @@ public class Stilts {
     private static ObjectFactory<TypedPlot2Task<?,?>> plot2TaskFactory_;
     private static ObjectFactory<ProcessingMode> modeFactory_;
     private static TableScheme[] stdSchemes_;
+    private static final Logger logger_ =
+        Logger.getLogger( "uk.ac.starlink.ttools" );
     static { init(); }
 
     public static final String VERSION_RESOURCE = "stilts.version";
@@ -50,7 +54,7 @@ public class Stilts {
         int status = invoker.invoke( args, new Runnable() {
             public void run() {
                 URLUtils.installCustomHandlers();
-                PropertyAuthenticator.installInstance( true );
+                AuthManager.getInstance().setUserInterface( getAuthUi() );
             }
         } );
         if ( status != 0 ) {
@@ -129,6 +133,26 @@ public class Stilts {
                                             Level.CONFIG );
     }
 
+    /**
+     * Returns the UserInterface instance to be used for authentication.
+     *
+     * @return   ui implementation
+     */
+    private static UserInterface getAuthUi() {
+        UserInterface propsUi = UserInterface.getPropertiesUi();
+        if ( propsUi != null ) {
+            String user = System.getProperty( UserInterface.USERNAME_PROP );
+            if ( user != null && user.trim().length() > 0 ) {
+                logger_.warning( "Automatic system-property-based "
+                               + "authentication for user " + user );
+            }
+            return propsUi;
+        }
+        else {
+            return UserInterface.CLI;
+        }
+    }
+
     /**
      * Initialises factories.
      */
@@ -172,6 +196,7 @@ public class Stilts {
         taskFactory_.register( "tcopy", taskPkg + "TableCopy" );
         taskFactory_.register( "tcube", taskPkg + "TableCube" );
         taskFactory_.register( "tgridmap", taskPkg + "GridDensityMap" );
+        taskFactory_.register( "tgroup", taskPkg + "TableGroup" );
         taskFactory_.register( "tjoin", taskPkg + "TableJoinN" );
         taskFactory_.register( "tloop", taskPkg + "TableLoop" );
         taskFactory_.register( "tmatch1", taskPkg + "TableMatch1" );
@@ -196,6 +221,8 @@ public class Stilts {
                   new Pair<String>( "plot2cube", plot2Pkg + "CubePlot2Task" ),
                   new Pair<String>( "plot2sphere",
                                     plot2Pkg + "SpherePlot2Task" ),
+                  new Pair<String>( "plot2corner",
+                                    plot2Pkg + "MatrixPlot2Task" ),
                   new Pair<String>( "plot2time", plot2Pkg + "TimePlot2Task" )
               ) ) {
             String name = pair.getItem1(); 
