@@ -2,7 +2,7 @@ package uk.ac.starlink.ttools.example;
 
 import java.awt.Color;
 import java.io.IOException;
-import javax.swing.Icon;
+import java.util.function.DoubleUnaryOperator;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.ttools.plot.BarStyle;
 import uk.ac.starlink.ttools.plot2.BasicCaptioner;
@@ -12,8 +12,9 @@ import uk.ac.starlink.ttools.plot2.Navigator;
 import uk.ac.starlink.ttools.plot2.Padding;
 import uk.ac.starlink.ttools.plot2.PlotLayer;
 import uk.ac.starlink.ttools.plot2.Plotter;
-import uk.ac.starlink.ttools.plot2.ShadeAxisFactory;
-import uk.ac.starlink.ttools.plot2.Span;
+import uk.ac.starlink.ttools.plot2.ShadeAxisKit;
+import uk.ac.starlink.ttools.plot2.Trimming;
+import uk.ac.starlink.ttools.plot2.ZoneContent;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
 import uk.ac.starlink.ttools.plot2.data.Coord;
 import uk.ac.starlink.ttools.plot2.data.DataSpec;
@@ -26,6 +27,7 @@ import uk.ac.starlink.ttools.plot2.geom.PlaneDataGeom;
 import uk.ac.starlink.ttools.plot2.geom.PlaneNavigator;
 import uk.ac.starlink.ttools.plot2.geom.PlanePlotType;
 import uk.ac.starlink.ttools.plot2.geom.PlaneSurfaceFactory;
+import uk.ac.starlink.ttools.plot2.geom.SideFlags;
 import uk.ac.starlink.ttools.plot2.layer.BinSizer;
 import uk.ac.starlink.ttools.plot2.layer.Combiner;
 import uk.ac.starlink.ttools.plot2.layer.Cumulation;
@@ -102,19 +104,26 @@ public class ApiPlanePlotter implements SinePlot.PlanePlotter {
         boolean yflip = false;
         String xlabel = "X axis";
         String ylabel = "Y axis";
+        DoubleUnaryOperator x2func = null;
+        DoubleUnaryOperator y2func = null;
+        String x2label = null;
+        String y2label = null;
         Captioner captioner = new BasicCaptioner();
+        SideFlags annotateFlags = SideFlags.ALL;
         double xyfactor = Double.NaN;
-        boolean grid = false;
         double xcrowd = 1;
         double ycrowd = 1;
         boolean minor = true;
-        Color gridColor = Color.BLACK;
+        boolean shadow = true;
+        Color gridColor = null;
         Color axlabelColor = Color.BLACK;
         PlaneSurfaceFactory.Profile profile =
             new PlaneSurfaceFactory.Profile( xlog, ylog, xflip, yflip,
-                                             xlabel, ylabel, captioner,
-                                             xyfactor, grid, xcrowd, ycrowd,
-                                             minor, gridColor, axlabelColor );
+                                             xlabel, ylabel, x2func, y2func,
+                                             x2label, y2label, captioner,
+                                             annotateFlags, xyfactor,
+                                             xcrowd, ycrowd, minor, shadow,
+                                             gridColor, axlabelColor );
 
         /* Set up a plot Aspect.  This is the initial data range,
          * and is subject to change by user navigation. */
@@ -123,15 +132,16 @@ public class ApiPlanePlotter implements SinePlot.PlanePlotter {
         PlaneAspect aspect = new PlaneAspect( xlimits, ylimits );
 
         /* We will not use optional decorations for this plot. */
-        Icon legend = null;
-        float[] legPos = null;
-        String title = null;
-        ShadeAxisFactory shadeFact = null;
-        Span shadeFixSpan = null;
+        Trimming trimming = null;
+        ShadeAxisKit shadeKit = null;
 
         /* Prepare the list of plot layers; in this case there is only one. */
         PlotLayer[] layers = { createScatterLayer( geom, table), };
 
+        /* Assemble a content object. */
+        ZoneContent<PlaneSurfaceFactory.Profile,PlaneAspect> content =
+            new ZoneContent<>( profile, aspect, layers );
+
         /* Prepare the data cache. */
         int nl = layers.length;
         DataSpec[] dataSpecs = new DataSpec[ nl ];
@@ -153,9 +163,8 @@ public class ApiPlanePlotter implements SinePlot.PlanePlotter {
 
         /* Construct and return the plot generator. */
         return new PlotGenerator<PlaneSurfaceFactory.Profile,PlaneAspect>
-                                ( layers, surfFact, profile, aspect,
-                                  legend, legPos, title, shadeFact,
-                                  shadeFixSpan, ptSel, compositor,
+                                ( surfFact, content, trimming,
+                                  shadeKit, ptSel, compositor,
                                   dataStore, xpix, ypix, padding );
     }
 
