@@ -30,7 +30,7 @@ public class RandomFilter extends BasicFilter implements ProcessingStep {
         };
     }
 
-    public ProcessingStep createStep( Iterator argIt ) {
+    public ProcessingStep createStep( Iterator<String> argIt ) {
         return this;
     }
 
