@@ -27,6 +27,11 @@ import uk.ac.starlink.pal.Pal;
  * <dd><p>A continuous measure in days since midnight at the start of
  *     17 November 1858.  Based on UTC.
  *     </p></dd>
+ * <dt>Julian Day (JD)</dt>
+ * <dd><p>MJD plus a fixed offset of 2400000.5.
+ *     The number of days since the notional creation of the universe,
+ *     midday on 1 Jan 4713 BC.
+ *     </p></dd>
  * <dt>ISO 8601</dt>
  * <dd><p>A string representation of the form 
  *     <code>yyyy-mm-ddThh:mm:ss.s</code>, where the <code>T</code>
@@ -75,6 +80,7 @@ public class Times {
     private final static String TIME_PATTERN = "HH:mm:ss";
     private final static TimeZone UTC = TimeZone.getTimeZone( "UTC" );
     private final static Pal pal = new Pal();
+    private final static long BCE_BOUNDARY_UNIXMILLIS = -62135769600000L;
 
     /** Regular expression for parsing ISO 8601 dates. */
     private final static Pattern ISO_REGEX = 
@@ -94,6 +100,9 @@ public class Times {
     /** Number of seconds per day. */
     private final static double SEC_PER_DAY = 60 * 60 * 24;
 
+    /** JD value for MJD = 0 (=2400000.5). */
+    public static final double MJD_OFFSET = 2400000.5;
+
     /**
      * Thread-local copy of a DateKit object.
      * It would be expensive to create new Calendar and DateFormat objects 
@@ -296,13 +305,14 @@ public class Times {
      * @param  jd  Julian day
      * @return   seconds since the Unix epoch
      */
-    public static double julianToUnixSec( double jd ) {
-        return mjdToUnixSec( julianToMjd( jd ) );
+    public static double jdToUnixSec( double jd ) {
+        return mjdToUnixSec( jdToMjd( jd ) );
     }
 
     /**
      * Converts a Modified Julian Date value to an ISO 8601-format date-time
      * string.  The output format is <code>yyyy-mm-ddThh:mm:ss</code>.
+     * If the result predates the Common Era, the string "(BCE)" is prepended.
      *
      * @example  <code>mjdToIso(53551.72917) = "2005-06-30T17:30:00"</code>
      *
@@ -310,12 +320,13 @@ public class Times {
      * @return  ISO 8601 format date corresponding to <code>mjd</code>
      */
     public static String mjdToIso( double mjd ) {
-        return formatMjd( mjd, getKit().isoDateTimeFormat_ );
+        return formatMjd( mjd, getKit().isoDateTimeFormat_, true );
     }
 
     /**
      * Converts a Modified Julian Date value to an ISO 8601-format date
      * string.  The output format is <code>yyyy-mm-dd</code>.
+     * If the result predates the Common Era, the string "(BCE)" is prepended.
      *
      * @example  <code>mjdToDate(53551.72917) = "2005-06-30"</code>
      *
@@ -323,7 +334,7 @@ public class Times {
      * @return  ISO 8601 format date corresponding to <code>mjd</code>
      */
     public static String mjdToDate( double mjd ) {
-        return formatMjd( mjd, getKit().isoDateFormat_ );
+        return formatMjd( mjd, getKit().isoDateFormat_, true );
     }
 
     /**
@@ -336,7 +347,7 @@ public class Times {
      * @return  ISO 8601 format time corresponding to <code>mjd</code>
      */
     public static String mjdToTime( double mjd ) {
-        return formatMjd( mjd, getKit().isoTimeFormat_ );
+        return formatMjd( mjd, getKit().isoTimeFormat_, false );
     }
 
     /**
@@ -386,7 +397,29 @@ public class Times {
      * @see     java.text.SimpleDateFormat
      */
     public static String formatMjd( double mjd, String format ) {
-        return formatMjd( mjd, getFormat( format ) );
+        return formatMjd( mjd, getFormat( format ), false );
+    }
+
+    /**
+     * Converts a Julian Day to Modified Julian Date.
+     * The calculation is simply <code>jd-2400000.5</code>.
+     *
+     * @param   jd  Julian day number
+     * @return   MJD value
+     */
+    public static double jdToMjd( double jd ) {
+        return jd - MJD_OFFSET;
+    }
+
+    /**
+     * Converts a Modified Julian Date to Julian Day.
+     * The calculation is simply <code>jd+2400000.5</code>.
+     *
+     * @param  mjd  MJD value
+     * @return  Julian day number
+     */
+    public static double mjdToJd( double mjd ) {
+        return mjd + MJD_OFFSET;
     }
 
     /**
@@ -537,16 +570,41 @@ public class Times {
     /**
      * Formats an MJD using a given date formatting object.
      *
+     * <p>Optionally, the string "<code>(BCE)</code>"
+     * can be prepended to the output for dates before the Common Era.
+     * This is rarely likely to be activated for astronomical data,
+     * except in the (perhaps not so rare) case of erroneous
+     * numeric date values present in data.  If this option is not used,
+     * a BCE date looks indistinguishable from a CE date.
+     * The choice of prepending and parenthesising the marker string is used
+     * firstly to make it visually obvious what's going on, and
+     * secondly so that BCE dates sort lexicographically before CE ones.
+     *
      * @param  mjd  modified Julian date
      * @param  format   format object
+     * @param  prependBce  prepend "(BCE)" for dates before the common era
+     *         
      * @return  formatted string
      */
-    private static String formatMjd( double mjd, DateFormat format ) {
+    private static String formatMjd( double mjd, DateFormat format,
+                                     boolean prependBce ) {
         if ( Double.isNaN( mjd ) || Double.isInfinite( mjd ) ) {
             return null;
         }
         else {
-            return format.format( new Date( mjdToUnixMillis( mjd ) ) );
+            long unixMillis = mjdToUnixMillis( mjd );
+            String txt = format.format( new Date( unixMillis ) );
+
+            /* I don't think there's a way of getting the DateFormat to
+             * do the BCE formatting itself; format GG adds "AD" or "BC",
+             * but we really just want the marker for the (exceptional)
+             * case in which it's pre-CE, without adding an AD or
+             * additional string manipulation in the vast majority of
+             * normal cases. */
+            if ( prependBce && unixMillis < BCE_BOUNDARY_UNIXMILLIS ) {
+                txt = "(BCE)" + txt;
+            }
+            return txt;
         }
     }
 
