@@ -4,7 +4,6 @@ import java.awt.BasicStroke;
 import java.awt.Color;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
-import java.awt.Insets;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.RenderingHints;
@@ -24,7 +23,9 @@ import uk.ac.starlink.ttools.plot2.CoordSequence;
 import uk.ac.starlink.ttools.plot2.Orientation;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Surface;
+import uk.ac.starlink.ttools.plot2.Surround;
 import uk.ac.starlink.ttools.plot2.Tick;
+import uk.ac.starlink.ttools.plot2.TickLook;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.util.SplitCollector;
 
@@ -69,6 +70,7 @@ public class CubeSurface implements Surface {
     private final double[] dOffs_;
 
     private static final Orientation ORIENTATION = Orientation.X;
+    private static final TickLook TICKLOOK = TickLook.STANDARD;
 
     /**
      * Constructor.
@@ -146,8 +148,8 @@ public class CubeSurface implements Surface {
         return new Rectangle( gxlo_, gylo_, gxhi_ - gxlo_, gyhi_ - gylo_ );
     }
 
-    public Insets getPlotInsets( boolean withScroll ) {
-        return new Insets( 0, 0, 0, 0 );
+    public Surround getSurround( boolean withScroll ) {
+        return new Surround();
     }
 
     public Captioner getCaptioner() {
@@ -1079,7 +1081,7 @@ public class CubeSurface implements Surface {
                                    logFlags_[ iaxis ],
                                    ( ! forward ) ^ flipFlags_[ iaxis ] );
         ax.drawLabels( ticks_[ iaxis ], labels_[ iaxis ],
-                       captioner_, ORIENTATION, false, g2 );
+                       captioner_, TICKLOOK, ORIENTATION, false, g2 );
         g2.setTransform( atf0 );
     }
 
