@@ -81,10 +81,6 @@ public abstract class HealpixDataGeom implements DataGeom {
         return 3;
     }
 
-    public boolean hasPosition() {
-        return true;
-    }
-
     public String getVariantName() {
         return variantName_;
     }
