@@ -6,6 +6,8 @@ import java.util.List;
 import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.Plotter;
+import uk.ac.starlink.ttools.plot2.GangerFactory;
+import uk.ac.starlink.ttools.plot2.SingleGangerFactory;
 import uk.ac.starlink.ttools.plot2.SurfaceFactory;
 import uk.ac.starlink.ttools.plot2.config.PerUnitConfigKey;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
@@ -14,6 +16,7 @@ import uk.ac.starlink.ttools.plot2.data.FloatingCoord;
 import uk.ac.starlink.ttools.plot2.layer.AreaForm;
 import uk.ac.starlink.ttools.plot2.layer.ArrayShapePlotter;
 import uk.ac.starlink.ttools.plot2.layer.CartesianErrorCoordSet;
+import uk.ac.starlink.ttools.plot2.layer.CartesianMultiPointForm;
 import uk.ac.starlink.ttools.plot2.layer.CartesianVectorCoordSet;
 import uk.ac.starlink.ttools.plot2.layer.CentralForm;
 import uk.ac.starlink.ttools.plot2.layer.ContourPlotter;
@@ -34,7 +37,6 @@ import uk.ac.starlink.ttools.plot2.layer.LabelPlotter;
 import uk.ac.starlink.ttools.plot2.layer.MarkArrayForm;
 import uk.ac.starlink.ttools.plot2.layer.MarkCombineArrayPlotter;
 import uk.ac.starlink.ttools.plot2.layer.MarkForm;
-import uk.ac.starlink.ttools.plot2.layer.MultiPointForm;
 import uk.ac.starlink.ttools.plot2.layer.PairLinkForm;
 import uk.ac.starlink.ttools.plot2.layer.PlaneCorrelationCoordSet;
 import uk.ac.starlink.ttools.plot2.layer.PlaneEllipseCoordSet;
@@ -61,21 +63,35 @@ public class PlanePlotType
         implements PlotType<PlaneSurfaceFactory.Profile,PlaneAspect> {
 
     private static PlaneDataGeom DATAGEOM = PlaneDataGeom.INSTANCE;
+    private static final PlaneSurfaceFactory.Config PLANE_CONFIG =
+        new PlaneSurfaceFactory.Config() {
+            public boolean has2dMetric() {
+                return true;
+            }
+            public boolean hasSecondaryAxes() {
+                return true;
+            }
+            public boolean labelFormattedPosition() {
+                return false;
+            }
+        };
     private static final PlanePlotType INSTANCE =
-        new PlanePlotType( createDefaultPlotters(), true );
+        new PlanePlotType( new PlaneSurfaceFactory( PLANE_CONFIG ),
+                           createDefaultPlotters() );
+
     private final PlaneSurfaceFactory surfFact_;
     private final Plotter<?>[] plotters_;
 
     /**
      * Constructor.
      *
+     * @param  surfFact  surface factory
      * @param  plotters  available plotters for use with this plot type
-     * @param  has2dMetric  true if it may make sense to measure distances
-     *                      that are not parallel to either axis
      */
-    public PlanePlotType( Plotter<?>[] plotters, boolean has2dMetric ) {
+    public PlanePlotType( PlaneSurfaceFactory surfFact,
+                          Plotter<?>[] plotters ) {
+        surfFact_ = surfFact;
         plotters_ = plotters;
-        surfFact_ = new PlaneSurfaceFactory( has2dMetric );
     }
 
     public DataGeom[] getPointDataGeoms() {
@@ -86,11 +102,15 @@ public class PlanePlotType
         return plotters_.clone();
     }
 
-    public SurfaceFactory<PlaneSurfaceFactory.Profile,PlaneAspect>
-                          getSurfaceFactory() {
+    public PlaneSurfaceFactory getSurfaceFactory() {
         return surfFact_;
     }
 
+    public GangerFactory<PlaneSurfaceFactory.Profile,PlaneAspect>
+                         getGangerFactory() {
+        return SingleGangerFactory.instance();
+    }
+
     public PaperTypeSelector getPaperTypeSelector() {
         return PaperTypeSelector.SELECTOR_2D;
     }
@@ -125,10 +145,10 @@ public class PlanePlotType
             MarkForm.SINGLE,
             SizeForm.getInstance(),
             SizeXyForm.getInstance(),
-            MultiPointForm
+            CartesianMultiPointForm
            .createVectorForm( "XYVector",
                               new CartesianVectorCoordSet( axisNames ), true ),
-            MultiPointForm
+            CartesianMultiPointForm
            .createErrorForm( "XYError",
                              CartesianErrorCoordSet
                             .createAllAxesErrorCoordSet( axisNames ),
