@@ -3,11 +3,11 @@ package uk.ac.starlink.ttools.plot2.geom;
 import java.awt.Color;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
-import java.awt.Insets;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.geom.Point2D;
 import java.util.Arrays;
+import java.util.function.DoubleUnaryOperator;
 import java.util.function.Supplier;
 import javax.swing.Icon;
 import uk.ac.starlink.ttools.plot2.Axis;
@@ -16,6 +16,7 @@ import uk.ac.starlink.ttools.plot2.Captioner;
 import uk.ac.starlink.ttools.plot2.CoordSequence;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Surface;
+import uk.ac.starlink.ttools.plot2.Surround;
 import uk.ac.starlink.ttools.plot2.Tick;
 import uk.ac.starlink.ttools.plot2.Ticker;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
@@ -28,6 +29,10 @@ import uk.ac.starlink.ttools.plot2.config.ConfigMap;
  */
 public class PlaneSurface implements Surface, PlanarSurface {
 
+    private final int gxlo_;
+    private final int gxhi_;
+    private final int gylo_;
+    private final int gyhi_;
     private final double dxlo_;
     private final double dxhi_;
     private final double dylo_;
@@ -36,17 +41,19 @@ public class PlaneSurface implements Surface, PlanarSurface {
     private final boolean ylog_;
     private final boolean xflip_;
     private final boolean yflip_;
-    private final int gxlo_;
-    private final int gxhi_;
-    private final int gylo_;
-    private final int gyhi_;
     private final Tick[] xticks_;
     private final Tick[] yticks_;
     private final String xlabel_;
     private final String ylabel_;
+    private final Tick[] x2ticks_;
+    private final Tick[] y2ticks_;
+    private final String x2label_;
+    private final String y2label_;
     private final Captioner captioner_;
+    private final SideFlags annotateflags_;
     private final Color gridcolor_;
     private final Color axlabelcolor_;
+    private final boolean islabelposition_;
     private final Axis xAxis_;
     private final Axis yAxis_;
 
@@ -69,17 +76,28 @@ public class PlaneSurface implements Surface, PlanarSurface {
      * @param  yticks  array of tickmark objects for Y axis
      * @param  xlabel  text for labelling X axis
      * @param  ylabel  text for labelling Y axis
+     * @param  x2ticks  array of tickmark objects for secondary X axis
+     * @param  y2ticks  array of tickmark objects for secondary Y axis
+     * @param  x2label  text for labelling secondary X axis
+     * @param  y2label  text for labelling secondary Y axis
      * @param  captioner  text renderer for axis labels etc, or null if absent
+     * @param  annotateflags  indicates which sides to annotate
      * @param  gridcolor  colour of grid lines, or null if not plotted
      * @param  axlabelcolor  colour of axis labels
+     * @param  islabelposition  whether formatted positions should include
+     *                          axis labels
      */
     public PlaneSurface( int gxlo, int gxhi, int gylo, int gyhi,
                          double dxlo, double dxhi, double dylo, double dyhi,
                          boolean xlog, boolean ylog,
                          boolean xflip, boolean yflip,
                          Tick[] xticks, Tick[] yticks,
-                         String xlabel, String ylabel, Captioner captioner,
-                         Color gridcolor, Color axlabelcolor ) {
+                         String xlabel, String ylabel,
+                         Tick[] x2ticks, Tick[] y2ticks,
+                         String x2label, String y2label,
+                         Captioner captioner, SideFlags annotateflags,
+                         Color gridcolor, Color axlabelcolor,
+                         boolean islabelposition ) {
         gxlo_ = gxlo;
         gxhi_ = gxhi;
         gylo_ = gylo;
@@ -96,9 +114,15 @@ public class PlaneSurface implements Surface, PlanarSurface {
         yticks_ = yticks;
         xlabel_ = xlabel;
         ylabel_ = ylabel;
+        x2ticks_ = x2ticks;
+        y2ticks_ = y2ticks;
+        x2label_ = x2label;
+        y2label_ = y2label;
         captioner_ = captioner;
+        annotateflags_ = annotateflags;
         gridcolor_ = gridcolor;
         axlabelcolor_ = axlabelcolor;
+        islabelposition_ = islabelposition;
         xAxis_ = Axis.createAxis( gxlo_, gxhi_, dxlo_, dxhi_, xlog_, xflip_ );
         yAxis_ = Axis.createAxis( gylo_, gyhi_, dylo_, dyhi_, ylog_,
                                   yflip_ ^ PlaneAxisAnnotation.INVERT_Y );
@@ -109,8 +133,8 @@ public class PlaneSurface implements Surface, PlanarSurface {
         return new Rectangle( gxlo_, gylo_, gxhi_ - gxlo_, gyhi_ - gylo_ );
     }
 
-    public Insets getPlotInsets( boolean withScroll ) {
-        return createAxisAnnotation().getPadding( withScroll );
+    public Surround getSurround( boolean withScroll ) {
+        return createAxisAnnotation().getSurround( withScroll );
     }
 
     /**
@@ -152,11 +176,18 @@ public class PlaneSurface implements Surface, PlanarSurface {
     }
 
     public String formatPosition( double[] dpos ) {
-        return new StringBuilder()
-            .append( formatPosition( xAxis_, dpos[ 0 ] ) )
+        StringBuilder sbuf = new StringBuilder();
+        sbuf.append( formatPosition( xAxis_, dpos[ 0 ] ) )
             .append( ", " )
-            .append( formatPosition( yAxis_, dpos[ 1 ] ) )
-            .toString();
+            .append( formatPosition( yAxis_, dpos[ 1 ] ) );
+        if ( islabelposition_ ) {
+            sbuf.append( " (" )
+                .append( xlabel_ )
+                .append( ", " )
+                .append( ylabel_ )
+                .append( ")" );
+        }
+        return sbuf.toString();
     }
 
     public Captioner getCaptioner() {
@@ -167,39 +198,40 @@ public class PlaneSurface implements Surface, PlanarSurface {
         Color color0 = g.getColor();
         g.setColor( Color.WHITE );
         g.fillRect( gxlo_, gylo_, gxhi_ - gxlo_, gyhi_ - gylo_ );
-        if ( gridcolor_ != null ) {
-            g.setColor( gridcolor_ );
-            for ( int it = 0; it < xticks_.length; it++ ) {
-                Tick tick = xticks_[ it ];
-                if ( tick.getLabel() != null ) {
-                    int gx = (int) xAxis_.dataToGraphics( tick.getValue() );
-                    g.drawLine( gx, gylo_, gx, gyhi_ );
-                }
-            }
-            for ( int it = 0; it < yticks_.length; it++ ) {
-                Tick tick = yticks_[ it ];
-                if ( tick.getLabel() != null ) {
-                    int gy = (int) yAxis_.dataToGraphics( tick.getValue() );
-                    g.drawLine( gxlo_, gy, gxhi_, gy );
-                }
-            }
-        }
         g.setColor( color0 );
     }
 
     public void paintForeground( Graphics g ) {
+        Color color0 = g.getColor();
+
+        /* Grid lines. */
+        if ( gridcolor_ != null ) {
+            Graphics gGrid = PlotUtil.createLineGraphics( g, gridcolor_ );
+            for ( Tick tick : xticks_ ) {
+                if ( tick.getLabel() != null ) {
+                    int gx = (int) xAxis_.dataToGraphics( tick.getValue() );
+                    gGrid.drawLine( gx, gylo_, gx, gyhi_ );
+                }
+            }
+            for ( Tick tick : yticks_ ) {
+                if ( tick.getLabel() != null ) {
+                    int gy = (int) yAxis_.dataToGraphics( tick.getValue() );
+                    gGrid.drawLine( gxlo_, gy, gxhi_, gy );
+                }
+            }
+        }
+
+        /* Axis labels. */
         if ( axlabelcolor_ != null ) {
-            Graphics2D g2 = (Graphics2D) g;
-            Color color0 = g2.getColor();
-            g2.setColor( axlabelcolor_ );
+            g.setColor( axlabelcolor_ );
             createAxisAnnotation().drawLabels( g );
 
             /* Boundary. */
-            g2.drawRect( gxlo_, gylo_, gxhi_ - gxlo_, gyhi_ - gylo_ );
-
-            /* Restore. */
-            g2.setColor( color0 );
+            g.drawRect( gxlo_, gylo_, gxhi_ - gxlo_, gyhi_ - gylo_ );
         }
+
+        /* Restore. */
+        g.setColor( color0 );
     }
 
     /**
@@ -320,34 +352,41 @@ public class PlaneSurface implements Surface, PlanarSurface {
      */
     private AxisAnnotation createAxisAnnotation() {
         return new PlaneAxisAnnotation( gxlo_, gxhi_, gylo_, gyhi_,
-                                        xAxis_, yAxis_, xticks_, yticks_,
-                                        xlabel_, ylabel_, captioner_,
-                                        true, true );
+                                        xAxis_, yAxis_,
+                                        xticks_, yticks_, xlabel_, ylabel_,
+                                        x2ticks_, y2ticks_, x2label_, y2label_,
+                                        captioner_, annotateflags_ );
     }
 
     @Override
     public boolean equals( Object o ) {
         if ( o instanceof PlaneSurface ) {
             PlaneSurface other = (PlaneSurface) o;
-            return this.xlog_ == other.xlog_
-                && this.ylog_ == other.ylog_
-                && this.xflip_ == other.xflip_
-                && this.yflip_ == other.yflip_
+            return this.gxlo_ == other.gxlo_
+                && this.gxhi_ == other.gxhi_
+                && this.gylo_ == other.gylo_
+                && this.gyhi_ == other.gyhi_
                 && this.dxlo_ == other.dxlo_
                 && this.dxhi_ == other.dxhi_
                 && this.dylo_ == other.dylo_
                 && this.dyhi_ == other.dyhi_
-                && this.gxlo_ == other.gxlo_
-                && this.gxhi_ == other.gxhi_
-                && this.gylo_ == other.gylo_
-                && this.gyhi_ == other.gyhi_
+                && this.xlog_ == other.xlog_
+                && this.ylog_ == other.ylog_
+                && this.xflip_ == other.xflip_
+                && this.yflip_ == other.yflip_
                 && Arrays.equals( this.xticks_, other.xticks_ )
                 && Arrays.equals( this.yticks_, other.yticks_ )
                 && PlotUtil.equals( this.xlabel_, other.xlabel_ )
                 && PlotUtil.equals( this.ylabel_, other.ylabel_ )
+                && Arrays.equals( this.x2ticks_, other.x2ticks_ )
+                && Arrays.equals( this.y2ticks_, other.y2ticks_ )
+                && PlotUtil.equals( this.x2label_, other.x2label_ )
+                && PlotUtil.equals( this.y2label_, other.y2label_ )
                 && this.captioner_.equals( other.captioner_ )
+                && this.annotateflags_.equals( other.annotateflags_ )
                 && PlotUtil.equals( this.gridcolor_, other.gridcolor_ )
-                && PlotUtil.equals( this.axlabelcolor_, other.axlabelcolor_ );
+                && PlotUtil.equals( this.axlabelcolor_, other.axlabelcolor_ )
+                && this.islabelposition_ == other.islabelposition_;
         }
         else {
             return false;
@@ -357,25 +396,31 @@ public class PlaneSurface implements Surface, PlanarSurface {
     @Override
     public int hashCode() {
         int code = 23023;
-        code = 23 * code + ( xlog_  ? 1 : 0 )
-                         + ( ylog_  ? 2 : 0 )
-                         + ( xflip_ ? 4 : 0 )
-                         + ( yflip_ ? 8 : 0 );
-        code = 23 * code + Float.floatToIntBits( (float) dxlo_ );
-        code = 23 * code + Float.floatToIntBits( (float) dxhi_ );
-        code = 23 * code + Float.floatToIntBits( (float) dylo_ );
-        code = 23 * code + Float.floatToIntBits( (float) dyhi_ );
         code = 23 * code + gxlo_;
         code = 23 * code + gxhi_;
         code = 23 * code + gylo_;
         code = 23 * code + gyhi_;
+        code = 23 * code + Float.floatToIntBits( (float) dxlo_ );
+        code = 23 * code + Float.floatToIntBits( (float) dxhi_ );
+        code = 23 * code + Float.floatToIntBits( (float) dylo_ );
+        code = 23 * code + Float.floatToIntBits( (float) dyhi_ );
+        code = 23 * code + ( xlog_  ? 1 : 0 )
+                         + ( ylog_  ? 2 : 0 )
+                         + ( xflip_ ? 4 : 0 )
+                         + ( yflip_ ? 8 : 0 );
         code = 23 * code + Arrays.hashCode( xticks_ );
         code = 23 * code + Arrays.hashCode( yticks_ );
         code = 23 * code + PlotUtil.hashCode( xlabel_ );
         code = 23 * code + PlotUtil.hashCode( ylabel_ );
+        code = 23 * code + Arrays.hashCode( x2ticks_ );
+        code = 23 * code + Arrays.hashCode( y2ticks_ );
+        code = 23 * code + PlotUtil.hashCode( x2label_ );
+        code = 23 * code + PlotUtil.hashCode( y2label_ );
         code = 23 * code + captioner_.hashCode();
+        code = 23 * code + annotateflags_.hashCode();
         code = 23 * code + PlotUtil.hashCode( gridcolor_ );
         code = 23 * code + PlotUtil.hashCode( axlabelcolor_ );
+        code = 23 * code + ( islabelposition_ ? 5 : 13 );
         return code;
     }
 
@@ -392,18 +437,28 @@ public class PlaneSurface implements Surface, PlanarSurface {
      * @param  yflip  whether to invert direction of Y axis
      * @param  xlabel  text for labelling X axis
      * @param  ylabel  text for labelling Y axis
+     * @param  x2func  function mapping primary to secondary X axis data coord,
+     *                 null for no secondary X axis
+     * @param  y2func  function mapping primary to secondary Y axis data coord,
+     *                 null for no secondary Y axis
+     * @param  x2label  secondary X axis label
+     * @param  y2label  secondary Y axis label
      * @param  captioner  text renderer for axis labels etc
+     * @param  annotateflags  which sides to annotate
      * @param  xyfactor   ratio (X axis unit length)/(Y axis unit length),
      *                    or NaN to use whatever bounds shape and
      *                    axis limits give you
-     * @param  grid   whether to draw grid lines
      * @param  xcrowd  crowding factor for tick marks on X axis;
      *                 1 is normal
      * @param  ycrowd  crowding factor for tick marks on Y axis;
      *                 1 is normal
      * @param  minor   whether to paint minor tick marks on axes
-     * @param  gridcolor  colour of grid lines, if plotted
+     * @param  shadow  whether to paint shadow ticks on opposite axes
+     *                 if no secondary axis
+     * @param  gridcolor  colour of grid lines, or null for none
      * @param  axlabelcolor  colour of axis labels
+     * @param  islabelposition  whether to include axis labels in
+     *                          formatted position text
      * @return  new plot surface
      */
     public static PlaneSurface createSurface( Rectangle plotBounds,
@@ -411,11 +466,17 @@ public class PlaneSurface implements Surface, PlanarSurface {
                                               boolean xlog, boolean ylog,
                                               boolean xflip, boolean yflip,
                                               String xlabel, String ylabel,
+                                              DoubleUnaryOperator x2func,
+                                              DoubleUnaryOperator y2func,
+                                              String x2label, String y2label,
                                               Captioner captioner,
-                                              double xyfactor, boolean grid,
+                                              SideFlags annotateflags,
+                                              double xyfactor,
                                               double xcrowd, double ycrowd,
-                                              boolean minor, Color gridcolor,
-                                              Color axlabelcolor ) {
+                                              boolean minor, boolean shadow,
+                                              Color gridcolor,
+                                              Color axlabelcolor,
+                                              boolean islabelposition ) {
         int gxlo = plotBounds.x;
         int gxhi = plotBounds.x + plotBounds.width;
         int gylo = plotBounds.y;
@@ -426,18 +487,13 @@ public class PlaneSurface implements Surface, PlanarSurface {
         double dyhi = aspect.getYMax();
         Ticker xTicker = xlog ? BasicTicker.LOG : BasicTicker.LINEAR;
         Ticker yTicker = ylog ? BasicTicker.LOG : BasicTicker.LINEAR;
-        Tick[] xticks = xTicker.getTicks( dxlo, dxhi, minor, captioner,
-                                          PlaneAxisAnnotation.X_ORIENT,
-                                          plotBounds.width, xcrowd );
-        Tick[] yticks = yTicker.getTicks( dylo, dyhi, minor, captioner,
-                                          PlaneAxisAnnotation.Y_ORIENT,
-                                          plotBounds.height, ycrowd );
-        gridcolor = grid ? gridcolor : null;
 
         /* Fixed ratio of X/Y data scales.  Interpret this by ensuring that
          * all of both requested data ranges is included, and one of them is
          * extended if necessary to accommodate the extra graphics space.
          * Only makes sense if both linear or both log. */
+        final Tick[] xticks;
+        final Tick[] yticks;
         if ( xyfactor > 0 && xlog == ylog ) {
             boolean log = xlog;
             double gx = gxhi - gxlo;
@@ -477,10 +533,37 @@ public class PlaneSurface implements Surface, PlanarSurface {
                                        PlaneAxisAnnotation.Y_ORIENT,
                                        plotBounds.height, 1 );
         }
+
+        /* Otherwise generate standard axis ticks. */
+        else {
+            xticks = xTicker.getTicks( dxlo, dxhi, minor, captioner,
+                                       PlaneAxisAnnotation.X_ORIENT,
+                                       plotBounds.width, xcrowd );
+            yticks = yTicker.getTicks( dylo, dyhi, minor, captioner,
+                                       PlaneAxisAnnotation.Y_ORIENT,
+                                       plotBounds.height, ycrowd );
+        }
+        Axis xAxis = Axis.createAxis( gxlo, gxhi, dxlo, dxhi, xlog, xflip );
+        Axis yAxis = Axis.createAxis( gylo, gyhi, dylo, dyhi, ylog,
+                                      yflip ^ PlaneAxisAnnotation.INVERT_Y );
+        Tick[] x2ticks = x2func == null
+                       ? ( shadow ? PlotUtil.getShadowTicks( xticks ) : null )
+                       : SlaveTicker.createTicker( xAxis, x2func )
+                                    .getTicks( dxlo, dxhi, minor, captioner,
+                                               PlaneAxisAnnotation.X2_ORIENT,
+                                               plotBounds.width, xcrowd );
+        Tick[] y2ticks = y2func == null
+                       ? ( shadow ? PlotUtil.getShadowTicks( yticks ) : null )
+                       : SlaveTicker.createTicker( yAxis, y2func )
+                                    .getTicks( dylo, dyhi, minor, captioner,
+                                               PlaneAxisAnnotation.Y2_ORIENT,
+                                               plotBounds.height, ycrowd );
         return new PlaneSurface( gxlo, gxhi, gylo, gyhi, dxlo, dxhi, dylo, dyhi,
-                                 xlog, ylog, xflip, yflip, xticks, yticks,
-                                 xlabel, ylabel, captioner, gridcolor,
-                                 axlabelcolor );
+                                 xlog, ylog, xflip, yflip,
+                                 xticks, yticks, xlabel, ylabel,
+                                 x2ticks, y2ticks, x2label, y2label,
+                                 captioner, annotateflags,
+                                 gridcolor, axlabelcolor, islabelposition );
     }
 
     /**
