@@ -1,11 +1,14 @@
 package uk.ac.starlink.ttools.plot2.geom;
 
+import gnu.jel.CompilationException;
 import java.awt.Color;
 import java.awt.Rectangle;
 import java.awt.geom.Point2D;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.function.DoubleUnaryOperator;
+import uk.ac.starlink.ttools.jel.JELFunction;
 import uk.ac.starlink.ttools.plot.Range;
 import uk.ac.starlink.ttools.plot2.Axis;
 import uk.ac.starlink.ttools.plot2.Captioner;
@@ -24,8 +27,11 @@ import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.ttools.plot2.config.ConfigMeta;
 import uk.ac.starlink.ttools.plot2.config.DoubleConfigKey;
+import uk.ac.starlink.ttools.plot2.config.Specifier;
+import uk.ac.starlink.ttools.plot2.config.StringConfigKey;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
 import uk.ac.starlink.ttools.plot2.config.SubrangeConfigKey;
+import uk.ac.starlink.ttools.plot2.config.TextFieldSpecifier;
 import uk.ac.starlink.ttools.plot2.data.DataStore;
 
 /**
@@ -37,53 +43,78 @@ import uk.ac.starlink.ttools.plot2.data.DataStore;
 public class PlaneSurfaceFactory
             implements SurfaceFactory<PlaneSurfaceFactory.Profile,PlaneAspect> {
 
+    private static final XyKeyPair<Double> MIN_XYKEY =
+        new XyKeyPair<Double>( a -> createAxisLimitKey( a, false ) );
+    private static final XyKeyPair<Double> MAX_XYKEY =
+        new XyKeyPair<Double>( a -> createAxisLimitKey( a, true ) );
+    private static final XyKeyPair<Subrange> SUBRANGE_XYKEY =
+        new XyKeyPair<Subrange>( a -> createAxisSubrangeKey( a ) );
+    private static final XyKeyPair<Boolean> LOG_XYKEY =
+        new XyKeyPair<Boolean>( a -> createAxisLogKey( a ) );
+    private static final XyKeyPair<Boolean> FLIP_XYKEY =
+        new XyKeyPair<Boolean>( a -> createAxisFlipKey( a ) );
+    private static final XyKeyPair<String> LABEL_XYKEY =
+        new XyKeyPair<String>( a -> StyleKeys.createAxisLabelKey( a ) );
+    private static final XyKeyPair<JELFunction> FUNC2_XYKEY =
+        new XyKeyPair<JELFunction>( a -> createSecondaryAxisFunctionKey( a ) );
+    private static final XyKeyPair<String> LABEL2_XYKEY =
+        new XyKeyPair<String>( a -> createSecondaryAxisLabelKey( a ) );
+    private static final XyKeyPair<Double> CROWD_XYKEY =
+        new XyKeyPair<Double>( a -> createAxisCrowdKey( a ) );
+    private static final XyKeyPair<Boolean> ANCHOR_XYKEY =
+        new XyKeyPair<Boolean>( a -> createAxisAnchorKey( a, false ) );
+
     /** Config key for X axis lower bound, before subranging. */
-    public static final ConfigKey<Double> XMIN_KEY =
-        createAxisLimitKey( "X", false );
+    public static final ConfigKey<Double> XMIN_KEY = MIN_XYKEY.getKeyX();
 
     /** Config key for X axis upper bound, before subranging. */
-    public static final ConfigKey<Double> XMAX_KEY =
-        createAxisLimitKey( "X", true );
+    public static final ConfigKey<Double> XMAX_KEY = MAX_XYKEY.getKeyX();
 
     /** Config key for X axis subrange. */
     public static final ConfigKey<Subrange> XSUBRANGE_KEY =
-        createAxisSubrangeKey( "X" );
+        SUBRANGE_XYKEY.getKeyX();
 
     /** Config key for Y axis lower bound, before subranging. */
-    public static final ConfigKey<Double> YMIN_KEY =
-        createAxisLimitKey( "Y", false );
+    public static final ConfigKey<Double> YMIN_KEY = MIN_XYKEY.getKeyY();
 
     /** Config key for Y axis upper bound, before subranging. */
-    public static final ConfigKey<Double> YMAX_KEY =
-        createAxisLimitKey( "Y", true );
+    public static final ConfigKey<Double> YMAX_KEY = MAX_XYKEY.getKeyY();
 
     /** Config key for Y axis subrange. */
     public static final ConfigKey<Subrange> YSUBRANGE_KEY =
-        createAxisSubrangeKey( "Y" );
+        SUBRANGE_XYKEY.getKeyY();
 
     /** Config key for X axis log scale flag. */
-    public static final ConfigKey<Boolean> XLOG_KEY =
-        createAxisLogKey( "X" );
+    public static final ConfigKey<Boolean> XLOG_KEY = LOG_XYKEY.getKeyX();
 
     /** Config key for Y axis log scale flag. */
-    public static final ConfigKey<Boolean> YLOG_KEY =
-        createAxisLogKey( "Y" );
+    public static final ConfigKey<Boolean> YLOG_KEY = LOG_XYKEY.getKeyY();
 
     /** Config key for X axis flip flag. */
-    public static final ConfigKey<Boolean> XFLIP_KEY =
-        createAxisFlipKey( "X" );
+    public static final ConfigKey<Boolean> XFLIP_KEY = FLIP_XYKEY.getKeyX();
 
     /** Config key for Y axis flip flag. */
-    public static final ConfigKey<Boolean> YFLIP_KEY =
-        createAxisFlipKey( "Y" );
+    public static final ConfigKey<Boolean> YFLIP_KEY = FLIP_XYKEY.getKeyY();
 
     /** Config key for X axis text label. */
-    public static final ConfigKey<String> XLABEL_KEY =
-        StyleKeys.createAxisLabelKey( "X" );
+    public static final ConfigKey<String> XLABEL_KEY = LABEL_XYKEY.getKeyX();
 
     /** Config key for Y axis text label.*/
-    public static final ConfigKey<String> YLABEL_KEY =
-        StyleKeys.createAxisLabelKey( "Y" );
+    public static final ConfigKey<String> YLABEL_KEY = LABEL_XYKEY.getKeyY();
+
+    /** Config key for secondary X axis function. */
+    public static final ConfigKey<JELFunction> X2FUNC_KEY =
+        FUNC2_XYKEY.getKeyX();
+
+    /** Config key for secondary Y axis function. */
+    public static final ConfigKey<JELFunction> Y2FUNC_KEY =
+        FUNC2_XYKEY.getKeyY();
+
+    /** Config key for secondary X axis text label. */
+    public static final ConfigKey<String> X2LABEL_KEY = LABEL2_XYKEY.getKeyX();
+
+    /** Config key for secondary Y axis text label. */
+    public static final ConfigKey<String> Y2LABEL_KEY = LABEL2_XYKEY.getKeyY();
 
     /** Config key for axis aspect ratio fix. */
     public static final ConfigKey<Double> XYFACTOR_KEY =
@@ -116,12 +147,10 @@ public class PlaneSurfaceFactory
         , false );
 
     /** Config key to control tick mark crowding on X axis. */
-    public static final ConfigKey<Double> XCROWD_KEY =
-        createAxisCrowdKey( "X" );
+    public static final ConfigKey<Double> XCROWD_KEY = CROWD_XYKEY.getKeyX();
 
     /** Config key to control tick mark crowding on Y axis. */
-    public static final ConfigKey<Double> YCROWD_KEY =
-        createAxisCrowdKey( "Y" );
+    public static final ConfigKey<Double> YCROWD_KEY = CROWD_XYKEY.getKeyY();
 
     /** Config key to select which axes navigation actions will operate on. */
     public static final ConfigKey<boolean[]> NAVAXES_KEY =
@@ -144,30 +173,44 @@ public class PlaneSurfaceFactory
         , new String[] { "X", "Y" } );
 
     /** Config key to anchor X axis during zooms. */
-    public static final ConfigKey<Boolean> XANCHOR_KEY =
-        createAxisAnchorKey( "X", false );
+    public static final ConfigKey<Boolean> XANCHOR_KEY = ANCHOR_XYKEY.getKeyX();
 
     /** Config key to anchor Y axis during zooms. */
-    public static final ConfigKey<Boolean> YANCHOR_KEY =
-        createAxisAnchorKey( "Y", false );
+    public static final ConfigKey<Boolean> YANCHOR_KEY = ANCHOR_XYKEY.getKeyY();
+
+    /** Default configuration for plane surface factory. */
+    public static final Config DFLT_CONFIG = new Config() {
+        public boolean has2dMetric() {
+            return true;
+        }
+        public boolean hasSecondaryAxes() {
+            return true;
+        }
+        public boolean labelFormattedPosition() {
+            return false;
+        }
+    };
 
     private final PlotMetric plotMetric_;
+    private final boolean hasSecondaryAxes_;
+    private final boolean labelFormattedPosition_;
 
     /**
      * Constructs a PlaneSurfaceFactory with default characteristics.
      */
     public PlaneSurfaceFactory() {
-        this( true );
+        this( DFLT_CONFIG );
     }
 
     /**
      * Constructs a PlaneSurfaceFactory with configurable characteristics.
      *
-     * @param  has2dMetric  true if it may make sense to measure distances
-     *                      that are not parallel to either axis
+     * @param  config  configuration options
      */
-    public PlaneSurfaceFactory( boolean has2dMetric ) {
-        plotMetric_ = new PlanePlotMetric( has2dMetric );
+    public PlaneSurfaceFactory( Config config ) {
+        plotMetric_ = new PlanePlotMetric( config.has2dMetric() );
+        hasSecondaryAxes_ = config.hasSecondaryAxes();
+        labelFormattedPosition_ = config.labelFormattedPosition();
     }
 
     public Surface createSurface( Rectangle plotBounds, Profile profile,
@@ -176,9 +219,12 @@ public class PlaneSurfaceFactory
         return PlaneSurface
               .createSurface( plotBounds, aspect,
                               p.xlog_, p.ylog_, p.xflip_, p.yflip_,
-                              p.xlabel_, p.ylabel_, p.captioner_,
-                              p.xyfactor_, p.grid_, p.xcrowd_, p.ycrowd_,
-                              p.minor_, p.gridcolor_, p.axlabelcolor_ );
+                              p.xlabel_, p.ylabel_, p.x2func_, p.y2func_,
+                              p.x2label_, p.y2label_, p.captioner_,
+                              p.annotateflags_, p.xyfactor_,
+                              p.xcrowd_, p.ycrowd_, p.minor_, p.shadow_,
+                              p.gridcolor_, p.axlabelcolor_,
+                              labelFormattedPosition_ );
     }
 
     public ConfigKey<?>[] getProfileKeys() {
@@ -190,14 +236,25 @@ public class PlaneSurfaceFactory
             YFLIP_KEY,
             XLABEL_KEY,
             YLABEL_KEY,
+        } ) );
+        if ( hasSecondaryAxes_ ) {
+            list.addAll( Arrays.asList( new ConfigKey<?>[] {
+                X2FUNC_KEY,
+                Y2FUNC_KEY,
+                X2LABEL_KEY,
+                Y2LABEL_KEY,
+            } ) );
+        }
+        list.addAll( Arrays.asList( new ConfigKey<?>[] {
             XYFACTOR_KEY,
             GRID_KEY,
             XCROWD_KEY,
             YCROWD_KEY,
             StyleKeys.MINOR_TICKS,
-            StyleKeys.GRID_COLOR,
-            StyleKeys.AXLABEL_COLOR,
+            StyleKeys.SHADOW_TICKS,
         } ) );
+        list.addAll( Arrays.asList( StyleKeys.GRIDCOLOR_KEYSET.getKeys() ) );
+        list.add( StyleKeys.AXLABEL_COLOR );
         list.addAll( Arrays.asList( StyleKeys.CAPTIONER.getKeys() ) );
         return list.toArray( new ConfigKey<?>[ 0 ] );
     }
@@ -209,17 +266,27 @@ public class PlaneSurfaceFactory
         boolean yflip = config.get( YFLIP_KEY );
         String xlabel = config.get( XLABEL_KEY );
         String ylabel = config.get( YLABEL_KEY );
+        DoubleUnaryOperator x2func = config.get( X2FUNC_KEY );
+        DoubleUnaryOperator y2func = config.get( Y2FUNC_KEY );
+        String x2label = config.get( X2LABEL_KEY );
+        String y2label = config.get( Y2LABEL_KEY );
         double xyfactor = config.get( XYFACTOR_KEY );
         boolean grid = config.get( GRID_KEY );
         double xcrowd = config.get( XCROWD_KEY );
         double ycrowd = config.get( YCROWD_KEY );
         boolean minor = config.get( StyleKeys.MINOR_TICKS );
-        Color gridcolor = config.get( StyleKeys.GRID_COLOR );
+        boolean shadow = config.get( StyleKeys.SHADOW_TICKS );
+        Color gridcolor = StyleKeys.GRIDCOLOR_KEYSET.createValue( config );
+        if ( ! grid ) {
+            gridcolor = null;
+        }
         Color axlabelcolor = config.get( StyleKeys.AXLABEL_COLOR );
         Captioner captioner = StyleKeys.CAPTIONER.createValue( config );
+        SideFlags annotateflags = SideFlags.ALL;
         return new Profile( xlog, ylog, xflip, yflip, xlabel, ylabel,
-                            captioner, xyfactor, grid, xcrowd, ycrowd, minor,
-                            gridcolor, axlabelcolor );
+                            x2func, y2func, x2label, y2label,
+                            captioner, annotateflags, xyfactor, xcrowd, ycrowd,
+                            minor, shadow, gridcolor, axlabelcolor );
     }
 
     public ConfigKey<?>[] getAspectKeys() {
@@ -292,6 +359,30 @@ public class PlaneSurfaceFactory
         return plotMetric_;
     }
 
+    /**
+     * Returns a list of those keys which apply equally to the X and Y axes.
+     *
+     * @return   paired X/Y key objects
+     */
+    public XyKeyPair<?>[] getXyKeyPairs() {
+        List<XyKeyPair<?>> list = new ArrayList<>();
+        list.addAll( Arrays.asList( new XyKeyPair<?>[] {
+            MIN_XYKEY,
+            MAX_XYKEY,
+            SUBRANGE_XYKEY,
+            LOG_XYKEY,
+            FLIP_XYKEY,
+            LABEL_XYKEY,
+            CROWD_XYKEY,
+            ANCHOR_XYKEY,
+        } ) );
+        if ( hasSecondaryAxes_ ) {
+            list.add( FUNC2_XYKEY );
+            list.add( LABEL2_XYKEY );
+        }
+        return list.toArray( new XyKeyPair<?>[ 0 ] );
+    }
+
     /**
      * Creates a config key for determining whether a named axis is
      * to be anchored at a data value of zero.
@@ -427,6 +518,119 @@ public class PlaneSurfaceFactory
         return StyleKeys.createCrowdKey( meta );
     }
 
+    /**
+     * Creates a config key for a secondary axis function.
+     *
+     * @param   primaryAxisName   name of primary axis, for instance "X"
+     * @return  new config key
+     */
+    public static ConfigKey<JELFunction>
+            createSecondaryAxisFunctionKey( String primaryAxisName ) {
+        String axname = primaryAxisName.toLowerCase();
+        final String varName = axname;
+        final String secondaryEdge;
+        if ( "X".equals( primaryAxisName ) ) {
+            secondaryEdge = "top";
+        }
+        else if ( "Y".equals( primaryAxisName ) ) {
+            secondaryEdge = "right";
+        }
+        else {
+            secondaryEdge = null;
+        }
+        ConfigMeta meta =
+            new ConfigMeta( axname + "2func",
+                            "Secondary " + primaryAxisName + " Axis"
+                          + " f(" + axname + ")" );
+        meta.setStringUsage( "<function-of-" + axname + ">" );
+        meta.setShortDescription( "Function of " + axname
+                                + " mapping primary to secondary axis" );
+        meta.setXmlDescription( new String[] {
+            "<p>Defines a secondary " + primaryAxisName + " axis",
+            "in terms of the primary one.",
+            "If a secondary axis is defined in this way,",
+            "then the axis opposite the primary one",
+            ( secondaryEdge == null ? ""
+                                    : "(i.e. on the " + secondaryEdge
+                                                      + " side of the plot)" ),
+            "will be annotated with the appropriate tickmarks.",
+            "</p>",
+            "<p>The value of this parameter is an",
+            "<ref id='jel'>algebraic expression</ref> in terms of the variable",
+            "<code>" + varName + "</code> giving the value",
+            "on the secondary " + primaryAxisName + " axis",
+            "corresponding to a given value",
+            "on the primary " + primaryAxisName + " axis.",
+            "</p>",
+            "<p>For instance, if the primary " + primaryAxisName + " axis",
+            "represents flux in Jansky,",
+            "then supplying the expression",
+            "\"<code>2.5*(23-log10(" + varName + "))-48.6</code>\"",
+            "(or \"<code>janskyToAb(" + varName + ")</code>\")",
+            "would annotate the secondary " + primaryAxisName + " axis",
+            "as AB magnitudes.",
+            "</p>",
+            "<p>The function supplied should be monotonic",
+            "and reasonably well-behaved,",
+            "otherwise the secondary axis annotation may not work well.",
+            "The application will attempt to make a sensible decision",
+            "about whether to use linear or logarithmic tick marks.",
+            "</p>",
+        } );
+        return new ConfigKey<JELFunction>( meta, JELFunction.class, null ) {
+            public JELFunction stringToValue( String fexpr )
+                    throws ConfigException {
+                if ( fexpr == null || fexpr.trim().length() == 0 ) {
+                    return null;
+                }
+                try {
+                    return new JELFunction( varName, fexpr );
+                }
+                catch ( CompilationException e ) {
+                    throw new ConfigException( this,
+                                               "Expression \"" + fexpr + "\""
+                                             + " not a function of " + varName
+                                             + ": " + e.getMessage(), e );
+                }
+            }
+            public String valueToString( JELFunction func ) {
+                return func == null ? null : func.getExpression();
+            }
+            public Specifier<JELFunction> createSpecifier() {
+                return new TextFieldSpecifier<JELFunction>( this, null );
+            }
+        };
+    }
+
+    /**
+     * Returns a labelling config key for a secondary axis.
+     *
+     * @param  primaryAxisName  name of primary axis to which the
+     *                          secondary axis relates
+     * @return  new key
+     */
+    public static ConfigKey<String>
+            createSecondaryAxisLabelKey( String primaryAxisName ) {
+        String axName = primaryAxisName;
+        ConfigMeta meta =
+            new ConfigMeta( primaryAxisName.substring( 0, 1 ).toLowerCase()
+                          + "2label",
+                            "Secondary " + primaryAxisName + " Axis Label" );
+        meta.setStringUsage( "<text>" );
+        meta.setShortDescription( "Label for secondary " + primaryAxisName
+                                + " axis" );
+        meta.setXmlDescription( new String[] {
+            "<p>Provides a string that will label the secondary",
+            primaryAxisName,
+            "axis.",
+            "This appears on the opposite side of the plot to the",
+            primaryAxisName,
+            "axis itself.",
+            "</p>",
+        } );
+        return new StringConfigKey( meta, null );
+    }
+
     /**
      * Utility method to interrogate axis range configuration variables
      * and work out the actual range to use on a given Cartesian axis.
@@ -508,6 +712,38 @@ public class PlaneSurfaceFactory
              : new PlaneAspect( xlimits, ylimits );
     }
 
+    /**
+     * Specifies configuration options for the PlaneSurfaceFactory.
+     * An instance of this interface is fed to the constructor.
+     */
+    public static interface Config {
+
+        /**
+         * Returns true if it may make sense to measure distances on
+         * the plane surfaces constructed.
+         *
+         * @return   true to allow 2d measurement
+         */
+        boolean has2dMetric();
+
+        /**
+         * Returns true if secondary axis labelling can be configured
+         * for the surface factory.
+         *
+         * @return  true to allow secondary axes
+         */
+        boolean hasSecondaryAxes();
+
+        /**
+         * Returns true if formatted position strings should be accompanied
+         * by the axis labels.
+         *
+         * @return  true to add axis labels to formatted position strings
+         * @see  uk.ac.starlink.ttools.plot2.Surface#formatPosition
+         */
+        boolean labelFormattedPosition();
+    }
+
     /**
      * PlotMetric implementation for plane surface.
      */
@@ -592,12 +828,17 @@ public class PlaneSurfaceFactory
         private final boolean yflip_;
         private final String xlabel_;
         private final String ylabel_;
+        private final DoubleUnaryOperator x2func_;
+        private final DoubleUnaryOperator y2func_;
+        private final String x2label_;
+        private final String y2label_;
         private final Captioner captioner_;
+        private final SideFlags annotateflags_;
         private final double xyfactor_;
-        private final boolean grid_;
         private final double xcrowd_;
         private final double ycrowd_;
         private final boolean minor_;
+        private final boolean shadow_;
         private final Color gridcolor_;
         private final Color axlabelcolor_;
 
@@ -610,24 +851,35 @@ public class PlaneSurfaceFactory
          * @param  yflip  whether to invert direction of Y axis
          * @param  xlabel  text for labelling X axis
          * @param  ylabel  text for labelling Y axis
+         * @param  x2func  function mapping primary to secondary X data coords,
+         *                 or null for no secondary X axis
+         * @param  y2func  function mapping primary to secondary Y data coords,
+         *                 or null for no secondary Y axis
+         * @param  x2label  text for labelling secondary X axis
+         * @param  y2label  text for labelling secondary Y axis
          * @param  captioner  text renderer for axis labels etc
+         * @param  annotateflags  which sides to annotate
          * @param  xyfactor   ratio (X axis unit length)/(Y axis unit length),
          *                    or NaN to use whatever bounds shape and
          *                    axis limits give you
-         * @param  grid   whether to draw grid lines
          * @param  xcrowd  crowding factor for tick marks on X axis;
          *                 1 is normal
          * @param  ycrowd  crowding factor for tick marks on Y axis;
          *                 1 is normal
          * @param  minor   whether to paint minor tick marks on axes
-         * @param  gridcolor  colour of grid lines, if plotted
+         * @param  shadow  whether to paint shadow ticks on opposite axes
+         *                 if no secondary axis
+         * @param  gridcolor  colour of grid lines, or null for none
          * @param  axlabelcolor  colour of axis labels
          */
         public Profile( boolean xlog, boolean ylog,
                         boolean xflip, boolean yflip,
-                        String xlabel, String ylabel, Captioner captioner,
-                        double xyfactor, boolean grid,
-                        double xcrowd, double ycrowd, boolean minor,
+                        String xlabel, String ylabel,
+                        DoubleUnaryOperator x2func, DoubleUnaryOperator y2func,
+                        String x2label, String y2label,
+                        Captioner captioner, SideFlags annotateflags,
+                        double xyfactor, double xcrowd, double ycrowd,
+                        boolean minor, boolean shadow,
                         Color gridcolor, Color axlabelcolor ) {
             xlog_ = xlog;
             ylog_ = ylog;
@@ -635,12 +887,17 @@ public class PlaneSurfaceFactory
             yflip_ = yflip;
             xlabel_ = xlabel;
             ylabel_ = ylabel;
+            x2func_ = x2func;
+            y2func_ = y2func;
+            x2label_ = x2label;
+            y2label_ = y2label;
             captioner_ = captioner;
+            annotateflags_ = annotateflags;
             xyfactor_ = xyfactor;
-            grid_ = grid;
             xcrowd_ = xcrowd;
             ycrowd_ = ycrowd;
             minor_ = minor;
+            shadow_ = shadow;
             gridcolor_ = gridcolor;
             axlabelcolor_ = axlabelcolor;
         }
@@ -653,5 +910,27 @@ public class PlaneSurfaceFactory
         public boolean[] getLogFlags() {
             return new boolean[] { xlog_, ylog_ };
         }
+
+        /**
+         * Returns a new profile instance the same as this one,
+         * except that the flags for which sides to annotate are replaced.
+         *
+         * @param  annotateFlags  which sides to annotate
+         * @param  addSecondary   if true, secondary axis annotations
+         *                        duplicating the primary axis ones
+         *                        will be added
+         * @return   adjusted profile
+         */
+        public Profile fixAnnotation( SideFlags annotateFlags,
+                                      boolean addSecondary ) {
+            return new Profile( xlog_, ylog_, xflip_, yflip_, xlabel_, ylabel_,
+                                addSecondary ? x -> x : x2func_,
+                                addSecondary ? y -> y : y2func_,
+                                addSecondary ? xlabel_ : x2label_,
+                                addSecondary ? ylabel_ : y2label_,
+                                captioner_, annotateFlags,
+                                xyfactor_, xcrowd_, ycrowd_, minor_, shadow_,
+                                gridcolor_, axlabelcolor_ );
+        }
     }
 }
