@@ -5,7 +5,6 @@ import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
-import java.awt.Insets;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.RenderingHints;
@@ -33,6 +32,7 @@ import uk.ac.starlink.ttools.plot2.CoordSequence;
 import uk.ac.starlink.ttools.plot2.LabelledLine;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Surface;
+import uk.ac.starlink.ttools.plot2.Surround;
 
 /**
  * Surface implementation for plotting on the celestial sphere.
@@ -166,12 +166,12 @@ public class SkySurface implements Surface {
         return new Rectangle( gxlo_, gylo_, gxhi_ - gxlo_, gyhi_ - gylo_ );
     }
 
-    public Insets getPlotInsets( boolean withScroll ) {
+    public Surround getSurround( boolean withScroll ) {
         GridLiner gl = gridColor_ == null ? null : createGridder();
         return gl == null
-             ? new Insets( 0, 0, 0, 0 )
-             : axLabeller_.createAxisAnnotation( gl, captioner_ )
-                          .getPadding( withScroll );
+             ? new Surround()
+             : axLabeller_.createAxisAnnotation( gl, captioner_, viewSystem_ )
+                          .getSurround( withScroll );
     }
 
     public void paintBackground( Graphics g ) {
@@ -204,7 +204,12 @@ public class SkySurface implements Surface {
                              antialias_ ? RenderingHints.VALUE_ANTIALIAS_ON
                                         : RenderingHints.VALUE_ANTIALIAS_OFF );
         if ( gridColor_ != null ) {
-            g2.setColor( gridColor_ );
+            Graphics2D gGrid =
+                (Graphics2D) PlotUtil.createLineGraphics( g2, gridColor_ );
+            Rectangle bounds1 = new Rectangle( getPlotBounds() );
+            bounds1.width += 1;
+            bounds1.height += 1;
+            gGrid.clip( bounds1 );
             double[][][] lines = gl.getLines();
             String[] labels = gl.getLabels();
             int nl = labels.length;
@@ -219,8 +224,10 @@ public class SkySurface implements Surface {
                     double[] seg = line[ is ];
                     path.lineTo( (float) seg[ 0 ], (float) seg[ 1 ] );
                 }
-                g2.draw( path );
+                gGrid.draw( path );
             }
+            gGrid.dispose();
+            g2.setColor( gridColor_ );
         }
         if ( skyFillsBounds_ ) {
             g2.draw( getPlotBounds() );
@@ -236,7 +243,7 @@ public class SkySurface implements Surface {
         }
         if ( axlabelColor_ != null ) {
             g2.setColor( axlabelColor_ );
-            axLabeller_.createAxisAnnotation( gl, captioner_ )
+            axLabeller_.createAxisAnnotation( gl, captioner_, viewSystem_ )
                        .drawLabels( g2 );
         }
         if ( scalebarColor_ != null ) {
@@ -689,7 +696,7 @@ public class SkySurface implements Surface {
      * in steradians.
      * It tries to return a representative value for the visible area.
      *
-     * @return   approximate linear size of a screen pixel in radians
+     * @return   approximate area of a screen pixel in steradians
      */
     public double pixelAreaSteradians() {
         Point2D screenCenter = new Point2D.Double( ( gxlo_ + gxhi_ ) * 0.5,
@@ -704,7 +711,7 @@ public class SkySurface implements Surface {
      * in steradians.
      *
      * @param   gpos  position of graphics pixel center
-     * @return  approximate linear size of pixel in radians,
+     * @return  approximate area of pixel in steradians,
      *          or NaN if pixel is not (all) on the sky
      */
     public double pixelAreaSteradians( Point2D gpos ) {
