@@ -85,7 +85,7 @@ public class SkySurfaceFactory
                 "before being plotted.",
                 "</p>",
             } )
-            , false )
+            , false, false )
        .setOptionUsage()
        .addOptionsXml();
 
@@ -115,7 +115,7 @@ public class SkySurfaceFactory
                 "to the same value as the view system.",
                 "</p>",
             } )
-            , false )
+            , false, true )
        .setOptionUsage()
        .addOptionsXml();
 
@@ -249,10 +249,10 @@ public class SkySurfaceFactory
             AXISLABELLER_KEY,
             SEX_KEY,
             CROWD_KEY,
-            StyleKeys.GRID_COLOR,
-            StyleKeys.AXLABEL_COLOR,
-            StyleKeys.GRID_ANTIALIAS,
         } ) );
+        list.addAll( Arrays.asList( StyleKeys.GRIDCOLOR_KEYSET.getKeys() ) );
+        list.add( StyleKeys.AXLABEL_COLOR );
+        list.add( StyleKeys.GRID_ANTIALIAS );
         list.addAll( Arrays.asList( StyleKeys.CAPTIONER.getKeys() ) );
         return list.toArray( new ConfigKey<?>[ 0 ] );
     }
@@ -265,7 +265,7 @@ public class SkySurfaceFactory
         SkyAxisLabeller axLabeller = config.get( AXISLABELLER_KEY );
         boolean sex = config.get( SEX_KEY );
         double crowd = config.get( CROWD_KEY );
-        Color gridColor = config.get( StyleKeys.GRID_COLOR );
+        Color gridColor = StyleKeys.GRIDCOLOR_KEYSET.createValue( config );
         Color axlabelColor = config.get( StyleKeys.AXLABEL_COLOR );
         Color scalebarColor = config.get( SCALEBAR_KEY ) ? axlabelColor : null;
         boolean antialias = config.get( StyleKeys.GRID_ANTIALIAS );
@@ -455,16 +455,7 @@ public class SkySurfaceFactory
         ConfigMeta meta =
             new ConfigMeta( "labelpos", "Grid Label Positioning" );
         meta.setShortDescription( "Position of sky grid labels" );
-        meta.setXmlDescription( new String[] {
-            "<p>Controls whether and where the numeric annotations",
-            "of the lon/lat axes are displayed.",
-            "The default option <code>" + auto + "</code>",
-            "usually does the sensible thing,",
-            "but other options exist to force labelling internally",
-            "or externally to the plot region,",
-            "or to remove numeric labels altogether.",
-            "</p>",
-        } );
+
         OptionConfigKey<SkyAxisLabeller> key =
                 new OptionConfigKey<SkyAxisLabeller>( meta,
                                                       SkyAxisLabeller.class,
@@ -488,7 +479,26 @@ public class SkySurfaceFactory
             }
         };
         key.setOptionUsage();
-        key.addOptionsXml();
+        meta.setXmlDescription( new String[] {
+            "<p>Controls whether and where the numeric annotations",
+            "of the lon/lat axes are displayed.",
+            "The default option <code>" + auto + "</code>",
+            "usually does the sensible thing,",
+            "but other options exist to force labelling internally",
+            "or externally to the plot region,",
+            "or to remove numeric labels altogether.",
+            "</p>",
+            key.getOptionsXml(),
+            "<p>The",
+            "<code>" + SkyAxisLabellers.EXTSYS.getLabellerName() + "</code>",
+            "and",
+            "<code>" + SkyAxisLabellers.INTSYS.getLabellerName() + "</code>",
+            "options use axis descriptions appropriate to the",
+            "View coordinate system for the current plot;",
+            "these options may not work well for plots which are all-sky",
+            "or show a substantial proportion of the sky.",
+            "</p>",
+        } );
         return key;
     }
 
