@@ -3,12 +3,12 @@ package uk.ac.starlink.ttools.plot2.geom;
 import java.awt.Color;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
-import java.awt.Insets;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.RenderingHints;
 import java.awt.geom.Point2D;
 import java.util.Arrays;
+import java.util.function.DoubleUnaryOperator;
 import java.util.function.Supplier;
 import uk.ac.starlink.ttools.plot2.Axis;
 import uk.ac.starlink.ttools.plot2.BasicTicker;
@@ -16,6 +16,7 @@ import uk.ac.starlink.ttools.plot2.Captioner;
 import uk.ac.starlink.ttools.plot2.CoordSequence;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Surface;
+import uk.ac.starlink.ttools.plot2.Surround;
 import uk.ac.starlink.ttools.plot2.Tick;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 
@@ -41,10 +42,14 @@ public class TimeSurface implements Surface, PlanarSurface {
     private final Tick[] yticks_;
     private final String tlabel_;
     private final String ylabel_;
+    private final Tick[] t2ticks_;
+    private final Tick[] y2ticks_;
+    private final String t2label_;
+    private final String y2label_;
     private final Captioner captioner_;
-    private final boolean grid_;
+    private final Color gridcolor_;
     private final TimeFormat tformat_;
-    private final boolean tannotate_;
+    private final SideFlags annotateflags_;
     private final Axis tAxis_;
     private final Axis yAxis_;
 
@@ -67,18 +72,24 @@ public class TimeSurface implements Surface, PlanarSurface {
      * @param  yticks  array of tickmark objects for Y axis
      * @param  tlabel  text for labelling time axis
      * @param  ylabel  text for labelling Y axis
+     * @param  t2ticks  array of tickmark objects for secondary time axis
+     * @param  y2ticks  array of tickmark objects for secondary Y axis
+     * @param  t2label  text for labelling secondary time axis
+     * @param  y2label  text for labelling secondary Y axis
      * @param  captioner  text renderer for axis labels etc
-     * @param  grid   whether to draw grid lines
+     * @param  gridcolor   grid line colour, or null for none
      * @param  tformat  time labelling format
-     * @param  tannotate  whether to annotate time axis
+     * @param  annotateflags  which sides to annotate
      */
     public TimeSurface( int gxlo, int gxhi, int gylo, int gyhi,
                         double dtlo, double dthi, double dylo, double dyhi,
                         boolean ylog, boolean yflip,
                         Tick[] tticks, Tick[] yticks,
                         String tlabel, String ylabel,
-                        Captioner captioner, boolean grid,
-                        TimeFormat tformat, boolean tannotate ) {
+                        Tick[] t2ticks, Tick[] y2ticks,
+                        String t2label, String y2label,
+                        Captioner captioner, Color gridcolor,
+                        TimeFormat tformat, SideFlags annotateflags ) {
         gxlo_ = gxlo;
         gxhi_ = gxhi;
         gylo_ = gylo;
@@ -93,10 +104,14 @@ public class TimeSurface implements Surface, PlanarSurface {
         yticks_ = yticks;
         tlabel_ = tlabel;
         ylabel_ = ylabel;
+        t2ticks_ = t2ticks;
+        y2ticks_ = y2ticks;
+        t2label_ = t2label;
+        y2label_ = y2label;
         captioner_ = captioner;
-        grid_ = grid;
+        gridcolor_ = gridcolor;
         tformat_ = tformat;
-        tannotate_ = tannotate;
+        annotateflags_ = annotateflags;
         tAxis_ = Axis.createAxis( gxlo_, gxhi_, dtlo_, dthi_, false, false );
         yAxis_ = Axis.createAxis( gylo_, gyhi_, dylo_, dyhi_, ylog_,
                                   yflip_ ^ INVERT_Y );
@@ -107,8 +122,8 @@ public class TimeSurface implements Surface, PlanarSurface {
         return new Rectangle( gxlo_, gylo_, gxhi_ - gxlo_, gyhi_ - gylo_ );
     }
 
-    public Insets getPlotInsets( boolean withScroll ) {
-        return createAxisAnnotation().getPadding( withScroll );
+    public Surround getSurround( boolean withScroll ) {
+        return createAxisAnnotation().getSurround( withScroll );
     }
 
     /**
@@ -162,28 +177,30 @@ public class TimeSurface implements Surface, PlanarSurface {
         Color color0 = g.getColor();
         g.setColor( Color.WHITE );
         g.fillRect( gxlo_, gylo_, gxhi_ - gxlo_, gyhi_ - gylo_ );
-        if ( grid_ ) {
-            g.setColor( Color.LIGHT_GRAY );
-            for ( int it = 0; it < tticks_.length; it++ ) {
-                Tick tick = tticks_[ it ];
-                if ( tick.getLabel() != null ) {
-                    int gx = (int) tAxis_.dataToGraphics( tick.getValue() );
-                    g.drawLine( gx, gylo_, gx, gyhi_ );
-                }
-            }
-            for ( int it = 0; it < yticks_.length; it++ ) {
-                Tick tick = yticks_[ it ];
-                if ( tick.getLabel() != null ) {
-                    int gy = (int) yAxis_.dataToGraphics( tick.getValue() );
-                    g.drawLine( gxlo_, gy, gxhi_, gy );
-                }
-            }
-        }
         g.setColor( color0 );
     }
 
     public void paintForeground( Graphics g ) {
         Color color0 = g.getColor();
+
+        /* Grid lines. */
+        if ( gridcolor_ != null ) {
+            Graphics gGrid = PlotUtil.createLineGraphics( g, gridcolor_ );
+            for ( Tick tick : tticks_ ) {
+                if ( tick.getLabel() != null ) {
+                    int gx = (int) tAxis_.dataToGraphics( tick.getValue() );
+                    gGrid.drawLine( gx, gylo_, gx, gyhi_ );
+                }
+            }
+            for ( Tick tick : yticks_ ) {
+                if ( tick.getLabel() != null ) {
+                    int gy = (int) yAxis_.dataToGraphics( tick.getValue() );
+                    gGrid.drawLine( gxlo_, gy, gxhi_, gy );
+                }
+            }
+        }
+
+        /* Axis labels. */
         g.setColor( Color.BLACK );
         createAxisAnnotation().drawLabels( g );
 
@@ -323,9 +340,10 @@ public class TimeSurface implements Surface, PlanarSurface {
      */
     private AxisAnnotation createAxisAnnotation() {
         return new PlaneAxisAnnotation( gxlo_, gxhi_, gylo_, gyhi_,
-                                        tAxis_, yAxis_, tticks_, yticks_,
-                                        tlabel_, ylabel_, captioner_,
-                                        tannotate_, true );
+                                        tAxis_, yAxis_,
+                                        tticks_, yticks_, tlabel_, ylabel_,
+                                        t2ticks_, y2ticks_, t2label_, y2label_,
+                                        captioner_, annotateflags_ );
     }
 
     @Override
@@ -345,10 +363,14 @@ public class TimeSurface implements Surface, PlanarSurface {
         code = 23 * code + Arrays.hashCode( yticks_ );
         code = 23 * code + PlotUtil.hashCode( tlabel_ );
         code = 23 * code + PlotUtil.hashCode( ylabel_ );
+        code = 23 * code + Arrays.hashCode( t2ticks_ );
+        code = 23 * code + Arrays.hashCode( y2ticks_ );
+        code = 23 * code + PlotUtil.hashCode( t2label_ );
+        code = 23 * code + PlotUtil.hashCode( y2label_ );
         code = 23 * code + captioner_.hashCode();
-        code = 23 * code + ( grid_ ? 11 : 13 );
+        code = 23 * code + PlotUtil.hashCode( gridcolor_ );
         code = 23 * code + tformat_.hashCode();
-        code = 23 * code + ( tannotate_ ? 17 : 23 );
+        code = 23 * code + annotateflags_.hashCode();
         return code;
     }
 
@@ -370,10 +392,14 @@ public class TimeSurface implements Surface, PlanarSurface {
                 && Arrays.equals( this.yticks_, other.yticks_ )
                 && PlotUtil.equals( this.tlabel_, this.tlabel_ )
                 && PlotUtil.equals( this.ylabel_, other.ylabel_ )
+                && Arrays.equals( this.t2ticks_, other.t2ticks_ )
+                && Arrays.equals( this.y2ticks_, other.y2ticks_ )
+                && PlotUtil.equals( this.t2label_, other.t2label_ )
+                && PlotUtil.equals( this.y2label_, other.y2label_ )
                 && this.captioner_.equals( other.captioner_ )
-                && this.grid_ == other.grid_
+                && PlotUtil.equals( this.gridcolor_, other.gridcolor_ )
                 && this.tformat_.equals( other.tformat_ )
-                && this.tannotate_ == other.tannotate_;
+                && this.annotateflags_.equals( other.annotateflags_ );
         }
         else {
             return false;
@@ -410,26 +436,38 @@ public class TimeSurface implements Surface, PlanarSurface {
      * @param  yflip  whether to invert direction of Y axis
      * @param  tlabel  text for labelling time axis
      * @param  ylabel  text for labelling Y axis
+     * @param  t2func  function mapping unix seconds to secondary time axis
+     *                 data coord, null for no secondary time axis
+     * @param  y2func  function mapping primary to secondary Y axis data coord,
+     *                 null for no secondary Y axis
+     * @param  t2label  secondary time axis label
+     * @param  y2label  secondary Y axis label
      * @param  captioner  text renderer for axis labels etc
-     * @param  grid   whether to draw grid lines
+     * @param  gridcolor   colour of grid lines, or null for none
      * @param  tformat  time labelling format
      * @param  tcrowd   crowding factor for tick marks on time axis;
      *                  1 is normal
      * @param  ycrowd   crowding factor for tick marks on Y axis;
      *                  1 is normal
      * @param  minor   whether to paint minor tick marks on axes
-     * @param  tannotate  whether to annotate time axis
+     * @param  shadow  whether to paint shadow ticks on opposite axes
+     *                 if no secondary axis
+     * @param  annotateflags  which axes to annotate
      * @return  new plot surface
      */
     public static TimeSurface createSurface( Rectangle plotBounds,
                                              TimeAspect aspect,
                                              boolean ylog, boolean yflip,
                                              String tlabel, String ylabel,
-                                             Captioner captioner, boolean grid,
+                                             DoubleUnaryOperator t2func,
+                                             DoubleUnaryOperator y2func,
+                                             String t2label, String y2label,
+                                             Captioner captioner,
+                                             Color gridcolor,
                                              TimeFormat tformat,
                                              double tcrowd, double ycrowd,
-                                             boolean minor,
-                                             boolean tannotate ) {
+                                             boolean minor, boolean shadow,
+                                             SideFlags annotateflags ) {
         int gxlo = plotBounds.x;
         int gxhi = plotBounds.x + plotBounds.width;
         int gylo = plotBounds.y;
@@ -446,8 +484,24 @@ public class TimeSurface implements Surface, PlanarSurface {
                        .getTicks( dylo, dyhi, minor, captioner,
                                   PlaneAxisAnnotation.Y_ORIENT,
                                   plotBounds.height, ycrowd );
+        Axis tAxis = Axis.createAxis( gxlo, gxhi, dtlo, dthi, false, false );
+        Axis yAxis = Axis.createAxis( gylo, gyhi, dylo, dyhi, ylog,
+                                      yflip ^ PlaneAxisAnnotation.INVERT_Y );
+        Tick[] t2ticks = t2func == null
+                       ? ( shadow ? PlotUtil.getShadowTicks( tticks ) : null )
+                       : new SlaveTicker( tAxis, t2func, BasicTicker.LINEAR )
+                        .getTicks( aspect.getTMin(), aspect.getTMax(), minor,
+                                   captioner, PlaneAxisAnnotation.X2_ORIENT,
+                                   plotBounds.width, tcrowd );
+        Tick[] y2ticks = y2func == null
+                       ? ( shadow ? PlotUtil.getShadowTicks( yticks ) : null )
+                       : SlaveTicker.createTicker( yAxis, y2func )
+                                    .getTicks( dylo, dyhi, minor, captioner,
+                                               PlaneAxisAnnotation.Y2_ORIENT,
+                                               plotBounds.height, ycrowd );
         return new TimeSurface( gxlo, gxhi, gylo, gyhi, dtlo, dthi, dylo, dyhi,
                                 ylog, yflip, tticks, yticks, tlabel, ylabel,
-                                captioner, grid, tformat, tannotate );
+                                t2ticks, y2ticks, t2label, y2label,
+                                captioner, gridcolor, tformat, annotateflags );
     }
 }
