@@ -1,10 +1,15 @@
 package uk.ac.starlink.ttools.plot2.geom;
 
+import gnu.jel.CompilationException;
+import java.awt.Color;
 import java.awt.Rectangle;
 import java.awt.geom.Point2D;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.function.DoubleUnaryOperator;
+import java.util.stream.Collectors;
+import uk.ac.starlink.ttools.jel.JELFunction;
 import uk.ac.starlink.ttools.plot.Range;
 import uk.ac.starlink.ttools.plot2.Axis;
 import uk.ac.starlink.ttools.plot2.Captioner;
@@ -17,13 +22,16 @@ import uk.ac.starlink.ttools.plot2.Subrange;
 import uk.ac.starlink.ttools.plot2.Surface;
 import uk.ac.starlink.ttools.plot2.SurfaceFactory;
 import uk.ac.starlink.ttools.plot2.config.BooleanConfigKey;
+import uk.ac.starlink.ttools.plot2.config.ConfigException;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
 import uk.ac.starlink.ttools.plot2.config.ConfigMeta;
 import uk.ac.starlink.ttools.plot2.config.OptionConfigKey;
+import uk.ac.starlink.ttools.plot2.config.Specifier;
 import uk.ac.starlink.ttools.plot2.config.StringConfigKey;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
 import uk.ac.starlink.ttools.plot2.config.SubrangeConfigKey;
+import uk.ac.starlink.ttools.plot2.config.TextFieldSpecifier;
 import uk.ac.starlink.ttools.plot2.config.TimeConfigKey;
 import uk.ac.starlink.ttools.plot2.data.DataStore;
 
@@ -109,6 +117,22 @@ public class TimeSurfaceFactory
     public static final ConfigKey<String> YLABEL_KEY =
         PlaneSurfaceFactory.YLABEL_KEY;
 
+    /** Config key for secondary time axis function. */
+    public static final ConfigKey<TimeJELFunction> T2FUNC_KEY =
+        createSecondaryTimeAxisFunctionKey();
+
+    /** Config key for secondary Y axis function. */
+    public static final ConfigKey<JELFunction> Y2FUNC_KEY =
+        PlaneSurfaceFactory.createSecondaryAxisFunctionKey( "Y" );
+
+    /** Config key for secondary time axis text label. */
+    public static final ConfigKey<String> T2LABEL_KEY =
+        PlaneSurfaceFactory.createSecondaryAxisLabelKey( "Time" );
+
+    /** Config key for secondary Y axis text label. */
+    public static final ConfigKey<String> Y2LABEL_KEY =
+        PlaneSurfaceFactory.createSecondaryAxisLabelKey( "Y" );
+
     /** Config key to determine if grid lines are drawn. */
     public static final ConfigKey<Boolean> GRID_KEY =
         new BooleanConfigKey(
@@ -145,8 +169,10 @@ public class TimeSurfaceFactory
         return TimeSurface
               .createSurface( plotBounds, aspect,
                               p.ylog_, p.yflip_, p.tlabel_, p.ylabel_,
-                              p.captioner_, p.grid_, p.tformat_,
-                              p.tcrowd_, p.ycrowd_, p.minor_, p.tannotate_ );
+                              p.t2func_, p.y2func_, p.t2label_, p.y2label_,
+                              p.captioner_, p.gridcolor_, p.tformat_,
+                              p.tcrowd_, p.ycrowd_, p.minor_, p.shadow_,
+                              p.annotateflags_ );
     }
 
     public ConfigKey<?>[] getProfileKeys() {
@@ -156,12 +182,18 @@ public class TimeSurfaceFactory
             YFLIP_KEY,
             TLABEL_KEY,
             YLABEL_KEY,
+            T2FUNC_KEY,
+            Y2FUNC_KEY,
+            T2LABEL_KEY,
+            Y2LABEL_KEY,
             GRID_KEY,
             TCROWD_KEY,
             YCROWD_KEY,
             TFORMAT_KEY,
             StyleKeys.MINOR_TICKS,
+            StyleKeys.SHADOW_TICKS,
         } ) );
+        list.addAll( Arrays.asList( StyleKeys.GRIDCOLOR_KEYSET.getKeys() ) );
         list.addAll( Arrays.asList( StyleKeys.CAPTIONER.getKeys() ) );
         return list.toArray( new ConfigKey<?>[ 0 ] );
     }
@@ -171,14 +203,24 @@ public class TimeSurfaceFactory
         boolean yflip = config.get( YFLIP_KEY );
         String tlabel = config.get( TLABEL_KEY );
         String ylabel = config.get( YLABEL_KEY );
-        boolean grid = config.get( GRID_KEY );
+        DoubleUnaryOperator t2func = config.get( T2FUNC_KEY );
+        DoubleUnaryOperator y2func = config.get( Y2FUNC_KEY );
+        String t2label = config.get( T2LABEL_KEY );
+        String y2label = config.get( Y2LABEL_KEY );
+        Color gridcolor = config.get( GRID_KEY )
+                        ? StyleKeys.GRIDCOLOR_KEYSET.createValue( config )
+                        : null;
         double tcrowd = config.get( TCROWD_KEY );
         double ycrowd = config.get( YCROWD_KEY );
         TimeFormat tformat = config.get( TFORMAT_KEY );
         boolean minor = config.get( StyleKeys.MINOR_TICKS );
+        boolean shadow = config.get( StyleKeys.SHADOW_TICKS );
         Captioner captioner = StyleKeys.CAPTIONER.createValue( config );
-        return new Profile( ylog, yflip, tlabel, ylabel, captioner,
-                            grid, tcrowd, ycrowd, tformat, minor, true );
+        SideFlags annotateflags = SideFlags.ALL;
+        return new Profile( ylog, yflip, tlabel, ylabel,
+                            t2func, y2func, t2label, y2label, captioner,
+                            gridcolor, tcrowd, ycrowd, tformat, minor, shadow,
+                            annotateflags );
     }
 
     public ConfigKey<?>[] getAspectKeys() {
@@ -331,6 +373,94 @@ public class TimeSurfaceFactory
         return key;
     }
 
+    /**
+     * Returns a config key for defining the secondary time axis.
+     *
+     * @return  new config key
+     */
+    private static ConfigKey<TimeJELFunction>
+            createSecondaryTimeAxisFunctionKey() {
+        final TimeJELFunction.TimeQuantity[] tqs =
+            TimeJELFunction.getTimeQuantities();
+        ConfigMeta meta =
+            new ConfigMeta( "t2func", "Secondary Time Axis Value" );
+        meta.setStringUsage( "<time-expr>" );
+        meta.setShortDescription( "Function of time value from primary axis" );
+        meta.setXmlDescription( new String[] {
+            "<p>Defines a secondary time axis in terms of the primary one.",
+            "If a secondary axis is defined in this way,",
+            "then the axis opposite the primary one,",
+            "i.e. the one on the top edge of the plot,",
+            "will be annotated with the appropriate tickmarks.",
+            "</p>",
+            "<p>The value of this parameter is an",
+            "<ref id='jel'>algebraic expression</ref>",
+            "giving the numeric value to be displayed on the secondary axis",
+            "corresponding to a given time value on the primary axis.",
+            "The expression may be given in terms of one of the following",
+            "variables:",
+            "<ul>",
+            Arrays.stream( tqs )
+                  .map( tq -> "<li><code>" + tq.getName() + "</code>: " +
+                              tq.getDescription() + "</li>\n" )
+                  .collect( Collectors.joining() ),
+            "</ul>",
+            "</p>",
+            "<p>In most cases, the value of this parameter will simply be",
+            "one of those variable names, for instance,",
+            "\"<code>mjd</code>\" to annotate the secondary axis",
+            "in Modified Julian Date.",
+            "However you can apply operations to these values in the usual way",
+            "if required, for instance to provide a differently offset",
+            "date scale.",
+            "</p>",
+            "<p>The function supplied should be monotonic",
+            "and reasonably well-behaved,",
+            "otherwise the secondary axis annotation may not work well.",
+            "Tick marks will always be applied on a linear scale.",
+            "Currently there is no way to annotate the secondary axis",
+            "with ISO-8601 dates or other non-numeric labels.",
+            "</p>",
+        } );
+        return new ConfigKey<TimeJELFunction>( meta, TimeJELFunction.class,
+                                               null ) {
+            public TimeJELFunction stringToValue( String fexpr )
+                    throws ConfigException {
+                if ( fexpr == null || fexpr.trim().length() == 0 ) {
+                    return null;
+                }
+                try {
+                    return new TimeJELFunction( fexpr );
+                }
+                catch ( CompilationException e ) {
+                    StringBuffer sbuf =new StringBuffer()
+                        .append( "Expresssion \"" )
+                        .append( fexpr )
+                        .append( "\" is not a function of " );
+                    int nq = tqs.length;
+                    for ( int iq = 0; iq < nq; iq++ ) {
+                        sbuf.append( tqs[ iq ].getName() );
+                        if ( iq < nq - 1 ) {
+                            sbuf.append( ", " );
+                        }
+                        if ( iq == nq - 2 ) {
+                            sbuf.append( "or " );
+                        }
+                    }
+                    sbuf.append( ": " )
+                        .append( e.getMessage() );
+                    throw new ConfigException( this, sbuf.toString() );
+                }
+            }
+            public String valueToString( TimeJELFunction func ) {
+                return func == null ? null : func.getExpression();
+            }
+            public Specifier<TimeJELFunction> createSpecifier() {
+                return new TextFieldSpecifier<TimeJELFunction>( this, null );
+            }
+        };
+    }
+
     /**
      * PlotMetric implementation for time plot surface.
      */
@@ -390,13 +520,18 @@ public class TimeSurfaceFactory
         private final boolean yflip_;
         private final String tlabel_;
         private final String ylabel_;
+        private final DoubleUnaryOperator t2func_;
+        private final DoubleUnaryOperator y2func_;
+        private final String t2label_;
+        private final String y2label_;
         private final Captioner captioner_;
-        private final boolean grid_;
+        private final Color gridcolor_;
         private final double tcrowd_;
         private final double ycrowd_;
         private final TimeFormat tformat_;
         private final boolean minor_;
-        private final boolean tannotate_;
+        private final boolean shadow_;
+        private final SideFlags annotateflags_;
 
         /**
          * Constructor.
@@ -405,31 +540,48 @@ public class TimeSurfaceFactory
          * @param  yflip  whether to invert direction of Y axis
          * @param  tlabel text for labelling time axis
          * @param  ylabel  text for labelling Y axis
+         * @param  t2func  function mapping unix time values to
+         *                 secondary time data coords,
+         *                 or null for no secondary time axis
+         * @param  y2func  function mapping primary to secondary Y data coords,
+         *                 or null for no secondary Y axis
+         * @param  t2label  text for labelling secondary time axis
+         * @param  y2label  text for labelling secondary Y axis
          * @param  captioner  text renderer for axis labels etc
-         * @param  grid   whether to draw grid lines
+         * @param  gridcolor   colour of grid lines, or null for none
          * @param  tcrowd  crowding factor for tick marks on time axis;
          *                 1 is normal
          * @param  ycrowd  crowding factor for tick marks on Y axis;
          *                 1 is normal
          * @param  tformat time labelling format
          * @param  minor   whether to draw minor ticks
-         * @param  tannotate  whether to annotate time axis
+         * @param  shadow  whether to paint shadow ticks on opposite axes
+         *                 if no secondary axis
+         * @param  annotateflags   which sides to annotate
          */
         public Profile( boolean ylog, boolean yflip,
-                        String tlabel, String ylabel, Captioner captioner,
-                        boolean grid, double tcrowd, double ycrowd,
-                        TimeFormat tformat, boolean minor, boolean tannotate ) {
+                        String tlabel, String ylabel,
+                        DoubleUnaryOperator t2func, DoubleUnaryOperator y2func,
+                        String t2label, String y2label, Captioner captioner,
+                        Color gridcolor, double tcrowd, double ycrowd,
+                        TimeFormat tformat, boolean minor, boolean shadow,
+                        SideFlags annotateflags ) {
             ylog_ = ylog;
             yflip_ = yflip;
             tlabel_ = tlabel;
             ylabel_ = ylabel;
+            t2func_ = t2func;
+            y2func_ = y2func;
+            t2label_ = t2label;
+            y2label_ = y2label;
             captioner_ = captioner;
-            grid_ = grid;
+            gridcolor_ = gridcolor;
             tcrowd_ = tcrowd;
             ycrowd_ = ycrowd;
             tformat_ = tformat;
             minor_ = minor;
-            tannotate_ = tannotate;
+            shadow_ = shadow;
+            annotateflags_ = annotateflags;
         }
 
         /**
@@ -443,15 +595,15 @@ public class TimeSurfaceFactory
 
         /**
          * Returns a new profile instance the same as this one,
-         * except that the flag for whether to annotate the time axis
-         * may be set.
+         * except that the flags for which sides to annotate are replaced.
          *
-         * @param   tannotate  whether to annotate time axis
+         * @param   annotateflags  which sides to annotate
          */
-        public Profile fixTimeAnnotation( boolean tannotate ) {
-            return new Profile( ylog_, yflip_, tlabel_, ylabel_, captioner_,
-                                grid_, tcrowd_, ycrowd_, tformat_, minor_,
-                                tannotate );
+        public Profile fixAnnotation( SideFlags annotateflags ) {
+            return new Profile( ylog_, yflip_, tlabel_, ylabel_,
+                                t2func_, y2func_, t2label_, y2label_,
+                                captioner_, gridcolor_, tcrowd_, ycrowd_,
+                                tformat_, minor_, shadow_, annotateflags );
         }
     }
 }
