@@ -11,6 +11,7 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.stream.IntStream;
 import uk.ac.starlink.table.DomainMapper;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableFactory;
@@ -19,20 +20,27 @@ import uk.ac.starlink.task.Parameter;
 import uk.ac.starlink.task.TaskException;
 import uk.ac.starlink.ttools.Stilts;
 import uk.ac.starlink.ttools.filter.SelectFilter;
+import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
 import uk.ac.starlink.ttools.plot2.Plotter;
 import uk.ac.starlink.ttools.plot2.SurfaceFactory;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
+import uk.ac.starlink.ttools.plot2.config.SkySysConfigKey;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
 import uk.ac.starlink.ttools.plot2.geom.CubePlotType;
+import uk.ac.starlink.ttools.plot2.geom.MatrixGangerFactory;
+import uk.ac.starlink.ttools.plot2.geom.MatrixPlotType;
+import uk.ac.starlink.ttools.plot2.geom.MatrixShape;
 import uk.ac.starlink.ttools.plot2.geom.PlanePlotType;
+import uk.ac.starlink.ttools.plot2.geom.PlaneSurfaceFactory;
 import uk.ac.starlink.ttools.plot2.geom.SpherePlotType;
 import uk.ac.starlink.ttools.plot2.geom.SkyPlotType;
 import uk.ac.starlink.ttools.plot2.geom.SkySys;
 import uk.ac.starlink.ttools.plot2.geom.SkySurfaceFactory;
 import uk.ac.starlink.ttools.plot2.geom.TimePlotType;
+import uk.ac.starlink.ttools.plot2.geom.XyKeyPair;
 import uk.ac.starlink.ttools.plot2.layer.ShapeForm;
 import uk.ac.starlink.ttools.plot2.layer.ShapeMode;
 import uk.ac.starlink.ttools.plot2.layer.ShapeModePlotter;
@@ -48,7 +56,6 @@ import uk.ac.starlink.ttools.task.SettingGroup;
 import uk.ac.starlink.ttools.task.TableNamer;
 import uk.ac.starlink.util.LoadException;
 
-
 /**
  * Represents an abstract model of a STILTS command line.
  * A list of parameter-value pairs along with basic parameter
@@ -71,6 +78,7 @@ public class StiltsPlot {
 
     private static final Collection<String> autoFormatNames_ =
         getAutoFormatNames();
+    private static final ConfigKey<?>[] AUX_KEYS = getAuxKeys(); 
 
     /**
      * Constructor.
@@ -126,8 +134,7 @@ public class StiltsPlot {
      */
     private static AbstractPlot2Task createTask( String taskName )
             throws LoadException {
-        return (AbstractPlot2Task)
-               Stilts.getTaskFactory().createObject( taskName );
+        return Stilts.getPlot2TaskFactory().createObject( taskName );
     }
 
     /**
@@ -151,8 +158,16 @@ public class StiltsPlot {
             throws LoadException {
         PlotType<P,A> plotType = plotSpec.getPlotType();
         Dimension extSize = plotSpec.getExtSize();
-        ZoneSpec[] zoneSpecs = plotSpec.getZoneSpecs();
+        ConfigMap globalConfig = plotSpec.getGlobalConfig();
+        ConfigMap[] zoneConfigs = plotSpec.getZoneConfigs();
+        TrimmingSpec[] trimSpecs = plotSpec.getTrimmingSpecs();
+        ShadeSpec[] shadeSpecs = plotSpec.getShadeSpecs();
         LayerSpec[] layerSpecs = plotSpec.getLayerSpecs();
+        GangerFactory<P,A> gangerFact = plotType.getGangerFactory();
+        boolean hasIndependentZones = gangerFact.hasIndependentZones();
+        int nz = zoneConfigs.length;
+        boolean isShadeGlobal = nz > 1 && shadeSpecs.length == 1;
+        boolean isTrimGlobal = nz > 1 && trimSpecs.length == 1;
         Suffixer zoneSuffixer = formatter.getZoneSuffixer();
         Suffixer layerSuffixer = formatter.getLayerSuffixer();
         TableNamer namer = formatter.getTableNamer();
@@ -175,105 +190,80 @@ public class StiltsPlot {
             createParamSetting( task.getPaddingParameter(),
                                 plotSpec.getPadding() ),
         } ) );
+        ConfigKey<?>[] gangKeys = gangerFact.getGangerKeys();
+        List<Setting> globalSettings = new ArrayList<>();
+        globalSettings.addAll( getConfigSettings( globalConfig, gangKeys ) );
+        globalSettings.add( null );
+        globalSettings.addAll( getGlobalSettings( plotSpec ) );
 
         /* Plot surface settings. */
         SurfaceFactory<P,A> sfact = plotType.getSurfaceFactory();
         ConfigKey<?>[] profileKeys = sfact.getProfileKeys();
         ConfigKey<?>[] aspectKeys = sfact.getAspectKeys();
-        ConfigKey<?>[] auxKeys = PlotUtil.arrayConcat(
-            StyleKeys.AUX_RAMP.getKeys(),
-            new ConfigKey<?>[] { StyleKeys.SHADE_LOW, StyleKeys.SHADE_HIGH }
-        );
-        Map<String,List<Setting>> zoneSettings =
-            new LinkedHashMap<String,List<Setting>>();
+        Map<String,List<Setting>> zoneSettings = new LinkedHashMap<>();
 
         /* Zone suffixes. */
-        int nz = zoneSpecs.length;
         String[] zkeys =
             zoneSuffixer.createSuffixes( nz ).toArray( new String[ 0 ] );
 
-        /* Set up zone adjusters to deal with zone-layer interactions. */
+        /* Set up adjusters to deal with plot-type specific situations. */
         ZoneAdjuster[] zadjusters = new ZoneAdjuster[ nz ];
         for ( int iz = 0; iz < nz; iz++ ) {
-            List<LayerSpec> lspecs = new ArrayList<LayerSpec>();
+            List<LayerSpec> lspecs = new ArrayList<>();
             for ( LayerSpec ls : layerSpecs ) {
                 if ( ls.getZoneIndex() == iz ) {
                     lspecs.add( ls );
                 }
             }
             zadjusters[ iz ] =
-                createZoneAdjuster( zoneSpecs[ iz ], lspecs, plotType );
+                createZoneAdjuster( zoneConfigs[ iz ], lspecs, plotType );
         }
 
         /* Per-zone settings. */
-        for ( int iz = 0; iz < nz; iz++ ) {
-            ZoneSpec zoneSpec = zoneSpecs[ iz ];
-            ConfigMap zoneConfig = zoneSpec.getConfig();
-            List<Setting> settings = new ArrayList<Setting>();
-            settings.addAll( getConfigSettings( zoneConfig, profileKeys ) );
-            settings.add( null );
-            settings.addAll( getConfigSettings( zoneConfig, aspectKeys ) );
-            settings.add( null );
-            if ( zoneSpec.getHasAux() ) {
-                ZoneSpec.RampSpec auxSpec = zoneSpec.getAuxSpec();
-                settings.addAll( getConfigSettings( zoneConfig, auxKeys ) );
+        if ( hasIndependentZones || nz == 1 ) {
+            for ( int iz = 0; iz < nz; iz++ ) {
+                ConfigMap zoneConfig = zoneConfigs[ iz ];
+                List<Setting> settings = new ArrayList<>();
+                settings.addAll( getConfigSettings( zoneConfig, profileKeys ) );
                 settings.add( null );
-                settings.add( createParamSetting(
-                                  task.createAuxVisibleParameter( null),
-                                  Boolean.valueOf( auxSpec != null ) ) );
-                if ( auxSpec != null ) {
-                    settings.add( createParamSetting(
-                                      task.createAuxLabelParameter( null ),
-                                      auxSpec.getLabel() ) );
-                    settings.add( createParamSetting(
-                                      task.createAuxCrowdParameter( null ),
-                                      auxSpec.getCrowding() ) );
-                }
+                settings.addAll( getConfigSettings( zoneConfig, aspectKeys ) );
                 settings.add( null );
+                TrimmingSpec trimSpec = isTrimGlobal ? null : trimSpecs[ iz ];
+                settings.addAll( getTrimSettings( task, trimSpec ) );
+                ShadeSpec shadeSpec = isShadeGlobal ? null : shadeSpecs[ iz ];
+                settings.addAll( getShadeSettings( task, shadeSpec ) );
+                zadjusters[ iz ].adjustZoneSettings( settings );
+                zoneSettings.put( zkeys[ iz ], settings );
             }
-            settings.add( createParamSetting( task.createTitleParameter( null ),
-                                              zoneSpec.getTitle() ) );
-            ZoneSpec.LegendSpec legSpec = zoneSpec.getLegendSpec();
-            boolean hasLegend = legSpec != null;
-            settings.add( createParamSetting( task.getLegendParameter(),
-                                              hasLegend ) );
-            if ( hasLegend ) {
-                settings.addAll( Arrays.asList( new Setting[] {
-                    createParamSetting( task.getLegendBorderParameter(),
-                                        legSpec.hasBorder() ),
-                    createParamSetting( task.getLegendOpaqueParameter(),
-                                        legSpec.isOpaque() ),
-                    createParamSetting( task
-                                       .createLegendPositionParameter( null ),
-                                        toDoubles( legSpec.getPosition() ) ),
-                } ) );
-            }
-            settings.add( null );
-            zadjusters[ iz ].adjustZoneSettings( settings );
-            zoneSettings.put( zkeys[ iz ], settings );
         }
 
+        /* Global shader and trimming settings if applicable. */
+        TrimmingSpec trimSpec = isTrimGlobal ? trimSpecs[ 0 ] : null;
+        globalSettings.addAll( getTrimSettings( task, trimSpec ) );
+        ShadeSpec shadeSpec = isShadeGlobal ? shadeSpecs[ 0 ] : null;
+        globalSettings.addAll( getShadeSettings( task, shadeSpec ) );
+
         /* Per-layer settings. */
-        Map<String,String> layerTypes = new LinkedHashMap<String,String>();
-        Map<String,List<Setting>> layerSettings =
-            new LinkedHashMap<String,List<Setting>>();
+        Map<String,String> layerTypes = new LinkedHashMap<>();
+        Map<String,List<Setting>> layerSettings = new LinkedHashMap<>();
         int nl = layerSpecs.length;
-        Collection<String> legKeys = new ArrayList<String>( nl );
+        Collection<String> legKeys = new ArrayList<>( nl );
         List<String> lkeys = layerSuffixer.createSuffixes( nl );
         boolean excludeLegend = false;
         for ( int il = 0; il < nl; il++ ) {
             LayerSpec lspec = layerSpecs[ il ];
             int iz = lspec.getZoneIndex();
-            ZoneSpec zoneSpec = zoneSpecs[ iz ];
-            List<Setting> lsettings = new ArrayList<Setting>();
+            List<Setting> lsettings = new ArrayList<>();
 
             /* Assign a layer suffix. */
             String lkey = lkeys.get( il );
 
             /* Zone identifier. */
-            lsettings.add( new Setting( AbstractPlot2Task.ZONE_PREFIX,
-                                        zkeys[ iz ], "" ) );
-            lsettings.add( null );
+            if ( iz >= 0 ) {
+                lsettings.add( new Setting( AbstractPlot2Task.ZONE_PREFIX,
+                                            zkeys[ iz ], "" ) );
+                lsettings.add( null );
+            }
 
             /* Work out the layer type and possibly associated shading type. */
             Plotter<?> plotter = lspec.getPlotter();
@@ -298,17 +288,23 @@ public class StiltsPlot {
 
             /* Input data coordinate settings, if any. */
             lsettings.addAll( createCoordSettings( lspec ) );
-            lsettings.addAll( zadjusters[ iz ].getLayerSettings( lspec ) );
             lsettings.add( null );
 
             /* Layer style configuration. */
             lsettings.addAll( modeSettings );
             lsettings.addAll( getConfigSettings( lspec.getConfig(),
                                                  plotter.getStyleKeys() ) );
+            if ( iz >= 0 ) {
+                zadjusters[ iz ].adjustLayerSettings( lspec, lsettings );
+            }
             lsettings.add( null );
 
             /* Legend label, if any. */
-            if ( zoneSpec.getLegendSpec() != null ) {
+            TrimmingSpec.LegendSpec legSpec =
+                  iz >= 0 && iz < trimSpecs.length && trimSpecs[ iz ] != null
+                ? trimSpecs[ iz ].getLegendSpec()
+                : null;
+            if ( legSpec != null ) {
                 String leglabel = lspec.getLegendLabel();
                 if ( leglabel != null ) {
                     lsettings.add(
@@ -358,6 +354,7 @@ public class StiltsPlot {
          * plot object. */
         List<SettingGroup> groups = new ArrayList<SettingGroup>();
         groups.addAll( toGroups( 1, taskSettings ) );
+        groups.addAll( toGroups( 1, globalSettings ) );
         groups.addAll( toGroups( 1, commonZoneSettings ) );
         for ( String zkey : zoneSettings.keySet() ) {
             List<Setting> zsettings = zoneSettings.get( zkey );
@@ -385,7 +382,10 @@ public class StiltsPlot {
      * @return  stilts task name
      */
     private static String getPlotTaskName( PlotType<?,?> ptype ) {
-        if ( ptype instanceof PlanePlotType ) {
+        if ( ptype instanceof MatrixPlotType ) {
+            return "plot2corner";
+        }
+        else if ( ptype instanceof PlanePlotType ) {
             return "plot2plane";
         }
         else if ( ptype instanceof SkyPlotType ) {
@@ -405,6 +405,70 @@ public class StiltsPlot {
         }
     }
 
+    /**
+     * Returns a list of settings relevant to the aux shade axis.
+     *
+     * @param  task   plot task
+     * @param  shadeSpec  shading specification
+     * @return  settings
+     */
+    private static List<Setting> getShadeSettings( AbstractPlot2Task task,
+                                                   ShadeSpec shadeSpec ) {
+        List<Setting> settings = new ArrayList<>();
+        if ( shadeSpec != null ) {
+            settings.addAll( getConfigSettings( shadeSpec.getConfig(),
+                                                AUX_KEYS ) );
+            settings.add( null );
+            boolean isVisible = shadeSpec.isVisible();
+            settings.add( createParamSetting(
+                              task.createAuxVisibleParameter( null ),
+                              Boolean.valueOf( isVisible ) ) );
+            if ( isVisible ) {
+                settings.addAll( Arrays.asList( new Setting[] {
+                    createParamSetting( task.createAuxLabelParameter( null ),
+                                        shadeSpec.getLabel() ),
+                    createParamSetting( task.createAuxCrowdParameter( null ),
+                                        shadeSpec.getCrowding() ),
+                } ) );
+            }
+            settings.add( null );
+        }
+        return settings;
+    }
+
+    /**
+     * Returns a list of settings relevant to plot trimmings.
+     *
+     * @param  task  plot task
+     * @param  trimSpec  trimming specification
+     * @return  settings
+     */
+    private static List<Setting> getTrimSettings( AbstractPlot2Task task,
+                                                  TrimmingSpec trimSpec ) {
+        List<Setting> settings = new ArrayList<>();
+        if ( trimSpec != null ) {
+            settings.add( createParamSetting( task.createTitleParameter( null ),
+                                              trimSpec.getTitle() ) );
+            TrimmingSpec.LegendSpec legSpec = trimSpec.getLegendSpec();
+            boolean hasLegend = legSpec != null;
+            settings.add( createParamSetting( task.getLegendParameter(),
+                                              hasLegend ) );
+            if ( hasLegend ) {
+                settings.addAll( Arrays.asList( new Setting[] {
+                    createParamSetting( task.getLegendBorderParameter(),
+                                        legSpec.hasBorder() ),
+                    createParamSetting( task.getLegendOpaqueParameter(),
+                                        legSpec.isOpaque() ),
+                    createParamSetting( task
+                                       .createLegendPositionParameter( null ),
+                                        toDoubles( legSpec.getPosition() ) ),
+                } ) );
+            }
+            settings.add( null );
+        }
+        return settings;
+    }
+
     /**
      * For each non-null setting in a supplied list, appends a given
      * suffix to the key part.  Null entries are left untouched.
@@ -442,9 +506,9 @@ public class StiltsPlot {
      */
     private static List<Setting>
             extractCommonSettings( Collection<List<Setting>> lists ) {
-        List<Setting> common = new ArrayList<Setting>();
+        List<Setting> common = new ArrayList<>();
         if ( lists.size() > 1 ) {
-            Set<String> allkeys = new LinkedHashSet<String>();
+            Set<String> allkeys = new LinkedHashSet<>();
             for ( List<Setting> list : lists ) {
                 for ( Setting s : list ) {
                     if ( s != null ) {
@@ -531,7 +595,7 @@ public class StiltsPlot {
     private static List<Setting> getConfigSettings( ConfigMap config,
                                                     ConfigKey<?>[] keys ) {
         int nk = keys.length;
-        List<Setting> settings = new ArrayList<Setting>( nk );
+        List<Setting> settings = new ArrayList<>( nk );
         for ( int ik = 0; ik < nk; ik++ ) {
             settings.add( createConfigSetting( keys[ ik ], config ) );
         }
@@ -547,9 +611,25 @@ public class StiltsPlot {
      */
     private static <T> Setting createConfigSetting( ConfigKey<T> key,
                                                     ConfigMap map ) {
-        return new Setting( getSettingKey( key ),
-                            key.valueToString( map.get( key ) ),
-                            key.valueToString( key.getDefaultValue() ) );
+        return createNamedConfigSetting( key, map, getSettingKey( key ) );
+    }
+
+    /**
+     * Creates a setting based on a given config option with an explicitly
+     * supplied setting key.
+     *
+     * @param  key   config key
+     * @param  config   config map that may contain information on value
+     * @param  settingKey  key for created setting object
+     * @return  new setting object
+     */
+    private static <T> Setting createNamedConfigSetting( ConfigKey<T> configKey,
+                                                         ConfigMap config,
+                                                         String settingKey ) {
+        return new Setting( settingKey,
+                            configKey.valueToString( config.get( configKey ) ),
+                            configKey.valueToString( configKey
+                                                    .getDefaultValue() ) );
     }
 
     /**
@@ -741,29 +821,44 @@ public class StiltsPlot {
      * zone/layer interactions not otherwise handled by the configuration
      * logic.
      *
-     * @param   zspec   specification for a zone
+     * @param   config   configuration in effect for the zone
      * @param   lspecs  array of specifications for all the layers that
      *                  appear within the given zone
      * @param  plotType  plot type
      * @return  appropriate zone adjuster, not null (but may be a noop)
      */
-    private static ZoneAdjuster createZoneAdjuster( ZoneSpec zspec,
+    private static ZoneAdjuster createZoneAdjuster( ConfigMap config,
                                                     List<LayerSpec> lspecs,
                                                     PlotType<?,?> plotType ) {
         if ( plotType instanceof SkyPlotType ) {
-            return new SkySysZoneAdjuster( zspec, lspecs );
+            return new SkySysZoneAdjuster( config, lspecs );
         }
         else {
             return new ZoneAdjuster() {
                 public void adjustZoneSettings( List<Setting> zsettings ) {
                 }
-                public List<Setting> getLayerSettings( LayerSpec lspec ) {
-                    return Collections.emptyList();
+                public void adjustLayerSettings( LayerSpec lspec,
+                                                 List<Setting> lsettings ) {
                 }
             };
         }
     }
 
+    /**
+     * Hook for returning special settings relating to a given PlotSpec.
+     *
+     * @param  plotSpec  plot specification
+     * @return   additional settings to add to the global list
+     */
+    private static List<Setting> getGlobalSettings( PlotSpec<?,?> plotSpec ) {
+        if ( plotSpec.getPlotType() instanceof MatrixPlotType ) {
+            return getMatrixGlobalSettings( plotSpec );
+        }
+        else {
+            return Collections.emptyList();
+        }
+    }
+
     /**
      * Groups a list of settings into zero or more SettingGroups.
      * A group is created for each non-empty run of Settings in the
@@ -776,10 +871,10 @@ public class StiltsPlot {
      */
     private static List<SettingGroup> toGroups( int level,
                                                 List<Setting> settings ) {
-        List<Setting> inList = new ArrayList<Setting>( settings );
+        List<Setting> inList = new ArrayList<>( settings );
         inList.add( null );
-        List<SettingGroup> glist = new ArrayList<SettingGroup>();
-        List<Setting> slist = new ArrayList<Setting>();
+        List<SettingGroup> glist = new ArrayList<>();
+        List<Setting> slist = new ArrayList<>();
         for ( Setting s : inList ) {
             if ( s != null ) {
                 slist.add( s );
@@ -787,7 +882,7 @@ public class StiltsPlot {
             else if ( slist.size() > 0 ) {
                 Setting[] line = slist.toArray( new Setting[ 0 ] );
                 glist.add( new SettingGroup( level, line ) );
-                slist = new ArrayList<Setting>();
+                slist = new ArrayList<>();
             }
         }
         return glist;
@@ -813,6 +908,20 @@ public class StiltsPlot {
         return list;
     }
 
+    /**
+     * Returns the list of config keys used for configuring the
+     * Aux shade axis.
+     *
+     * @return  shade axis config keys
+     */
+    private static ConfigKey<?>[] getAuxKeys() {
+        List<ConfigKey<?>> keys = new ArrayList<>();
+        keys.addAll( Arrays.asList( StyleKeys.AUX_RAMP.getKeys() ) );
+        keys.add( StyleKeys.SHADE_LOW );
+        keys.add( StyleKeys.SHADE_HIGH );
+        return keys.toArray( new ConfigKey<?>[ 0 ] );
+    }
+
     /**
      * Interface for an object that can tweak settings in a way
      * that depends on on the way that both a plot zone and the
@@ -837,10 +946,106 @@ public class StiltsPlot {
          *
          * @param  lspec  specification for one of the layers that this
          *                adjuster is configured for
-         * @return   list of zero or more settings to add to the layer
-         *           configuration
+         * @param  lsettings  mutable list of settings objects
+         *                    for the layer to be adjusted
          */
-        List<Setting> getLayerSettings( LayerSpec lspec );
+        void adjustLayerSettings( LayerSpec lspec, List<Setting> lsettings );
+    }
+
+    /**
+     * Performs special processing to provide MatrixPlot-specific setttings.
+     *
+     * @param  plotSpec  plot specification
+     * @return  global settings
+     */
+    private static List<Setting>
+            getMatrixGlobalSettings( PlotSpec<?,?> plotSpec ) {
+
+        /* Prepare required information from the plotspec. */
+        PlotType<?,?> plotType = plotSpec.getPlotType();
+        GangerFactory<?,?> gangerFact0 = plotType.getGangerFactory();
+        SurfaceFactory<?,?> surfFact0 = plotType.getSurfaceFactory();
+        if ( ! ( gangerFact0 instanceof MatrixGangerFactory ) ||
+             ! ( surfFact0 instanceof PlaneSurfaceFactory ) ) {
+            assert false;
+            return Collections.emptyList();
+        }
+        MatrixGangerFactory gangerFact = (MatrixGangerFactory) gangerFact0;
+        PlaneSurfaceFactory surfFact = (PlaneSurfaceFactory) surfFact0;
+        Plotter<?>[] plotters = Arrays.stream( plotSpec.getLayerSpecs() )
+                                      .map( LayerSpec::getPlotter )
+                                      .toArray( n -> new Plotter<?>[ n ] );
+        ConfigMap globalConfig = plotSpec.getGlobalConfig();
+        ConfigMap[] zoneConfigs = plotSpec.getZoneConfigs();
+        MatrixShape shape = gangerFact.getShape( globalConfig, plotters );
+        int nc = shape.getWidth();
+        int nz = shape.getCellCount();
+        assert zoneConfigs.length == nz;
+        String[] coordNames =
+            IntStream.range( 0, nc )
+                     .mapToObj( MatrixPlotType::getCoordName )
+                     .toArray( n -> new String[ n ] );
+        XyKeyPair<?>[] xyKeyPairs = surfFact.getXyKeyPairs();
+
+        /* Go through each zone, extracting configuration information
+         * specific to the X and Y axes.  These have to be converted to
+         * settings with different names corresponding to the numbered
+         * axes (X1, X2, ...) used by the matrix plot UI.
+         * Each numbered axis with all its settings is encountered
+         * multiple times; because of the way that the plots are set up,
+         * the setting values ought to be the same each time,
+         * so the settings (which in any case have to be single-valued)
+         * are only stored the first time round is stored (in maps). */
+        List<Map<String,Setting>> settingMaps = new ArrayList<>( nc );
+        for ( int ic = 0; ic < nc; ic++ ) {
+            settingMaps.add( new LinkedHashMap<String,Setting>() );
+        }
+        for ( int iz = 0; iz < nz; iz++ ) {
+            ConfigMap zconfig = zoneConfigs[ iz ];
+            MatrixShape.Cell cell = shape.getCell( iz );
+            int ix = cell.getX();
+            int iy = cell.getY();
+
+            /* Avoid diagonal cells, which are histogram like.
+             * Although one of the axes is a numbered coordinate in this case,
+             * the other one is something else (like histogram count),
+             * and its configuration shouldn't be applied to a numbered axis.
+             * This does mean that the configuration of those histogram
+             * axis is simply not recorded; there is currently no way
+             * to specify these configuration items in the stilts UI.
+             * We could try to identify the non-weird axis and use that only,
+             * but the config for this should get picked up when looking at
+             * one of the other cells.  Unless it's a very small matrix. */
+            if ( ix != iy ) {
+                for ( XyKeyPair<?> xyPair : xyKeyPairs ) {
+                    String xname =
+                        getSettingKey( xyPair.createKey( coordNames[ ix ] ) );
+                    String yname =
+                        getSettingKey( xyPair.createKey( coordNames[ iy ] ) );
+                    Map<String,Setting> xmap = settingMaps.get( ix );
+                    Map<String,Setting> ymap = settingMaps.get( iy );
+                    if ( ! xmap.containsKey( xname ) ) {
+                        xmap.put( xname,
+                                  createNamedConfigSetting( xyPair.getKeyX(),
+                                                            zconfig, xname ) );
+                    }
+                    if ( ! ymap.containsKey( yname ) ) {
+                        ymap.put( yname,
+                                  createNamedConfigSetting( xyPair.getKeyY(),
+                                                            zconfig, yname ) );
+                    }
+                }
+            }
+        }
+
+        /* Prepare result for return, grouped by coord index for
+         * more comprehensible presentation. */
+        List<Setting> settings = new ArrayList<>();
+        for ( Map<String,Setting> settingMap : settingMaps ) {
+            settings.addAll( settingMap.values() );
+            settings.add( null );
+        }
+        return settings;
     }
 
     /**
@@ -854,28 +1059,31 @@ public class StiltsPlot {
 
         private static final ConfigKey<SkySys> VIEWSYS_KEY =
             SkySurfaceFactory.VIEWSYS_KEY;
-        private static final ConfigKey<SkySys> DATASYS_KEY =
-            SkySurfaceFactory.DATASYS_KEY;
         private final SkySys viewsys_;
         private final boolean sysDiffers_;
 
         /**
          * Constructor.
          *
-         * @param  lspec  specification for one of the layers that this
-         *                adjuster is configured for
-         * @return   list of zero or more settings to add to the layer
-         *           configuration
+         * @param  zconfig  zone configuration
+         * @param  lspecs  layer specifiers
          */
-        SkySysZoneAdjuster( ZoneSpec zspec, List<LayerSpec> lspecs ) {
-            ConfigMap zconfig = zspec.getConfig();
+        SkySysZoneAdjuster( ConfigMap zconfig, List<LayerSpec> lspecs ) {
             viewsys_ = getExplicitValue( VIEWSYS_KEY, zconfig );
             boolean differs = false;
             for ( LayerSpec lspec : lspecs ) {
-                SkySys datasys =
-                    getExplicitValue( DATASYS_KEY, lspec.getConfig() );
-                if ( datasys != null && ! datasys.equals( viewsys_ ) ) {
-                    differs = true;
+                ConfigMap lconfig = lspec.getConfig();
+                for ( ConfigKey<?> key : lconfig.keySet() ) {
+                    if ( key instanceof SkySysConfigKey ) {
+                        SkySysConfigKey sysKey = (SkySysConfigKey) key;
+                        if ( sysKey.isViewComparison() ) {
+                            SkySys cmpsys = lconfig.get( sysKey );
+                            if ( cmpsys != null &&
+                                 ! cmpsys.equals( viewsys_ ) ) {
+                                differs = true;
+                            }
+                        }
+                    }
                 }
             }
             sysDiffers_ = differs;
@@ -892,16 +1100,33 @@ public class StiltsPlot {
             }
         }
 
-        public List<Setting> getLayerSettings( LayerSpec lspec ) {
-            List<Setting> list = new ArrayList<Setting>();
+        public void adjustLayerSettings( LayerSpec lspec,
+                                         List<Setting> lsettings ) {
             ConfigMap lconfig = lspec.getConfig();
-            SkySys datasys = getExplicitValue( DATASYS_KEY, lconfig );
-            if ( datasys != null ) {
-                Setting ls = createConfigSetting( DATASYS_KEY, lconfig );
-                String dflt = sysDiffers_ ? null : ls.getStringValue();
-                list.add( ls.resetDefault( dflt ) );
+            for ( ConfigKey<?> key : lconfig.keySet() ) {
+                if ( key instanceof SkySysConfigKey ) {
+                    SkySysConfigKey sysKey = (SkySysConfigKey) key;
+                    if ( sysKey.isViewComparison() ) {
+                        int isys = -1;
+                        for ( int i = 0; i < lsettings.size(); i++ ) {
+                            Setting ls = lsettings.get( i );
+                            if ( ls != null &&
+                                 ls.getKey().equals( getSettingKey( sysKey ))) {
+                                isys = i;
+                            }
+                        }
+                        if ( isys < 0 ) {
+                            lsettings.add( createConfigSetting( sysKey,
+                                                                lconfig ) );
+                            isys = lsettings.size() - 1;
+                        }
+                        Setting sysSetting = lsettings.get( isys );
+                        String dflt = sysDiffers_ ? null
+                                                  : sysSetting.getStringValue();
+                        lsettings.set( isys, sysSetting.resetDefault( dflt ) );
+                    }
+                }
             }
-            return list;
         }
     }
 }
