@@ -14,16 +14,23 @@ import java.util.HashSet;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.regex.Pattern;
+import java.util.stream.Collectors;
+import org.w3c.dom.Element;
+import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 import org.xml.sax.SAXException;
+import uk.ac.starlink.auth.AuthManager;
 import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.RowSequence;
 import uk.ac.starlink.table.StarTable;
+import uk.ac.starlink.ttools.votlint.VocabChecker;
 import uk.ac.starlink.util.Compression;
 import uk.ac.starlink.util.ContentType;
 import uk.ac.starlink.util.DOMUtils;
-import uk.ac.starlink.util.URLUtils;
+import uk.ac.starlink.vo.DatalinkVersion;
+import uk.ac.starlink.vo.Ivoid;
 import uk.ac.starlink.vo.datalink.LinkColMap;
 import uk.ac.starlink.vo.datalink.LinksDoc;
 import uk.ac.starlink.vo.datalink.ServiceInvoker;
@@ -48,11 +55,12 @@ import uk.ac.starlink.votable.datalink.ServiceParam;
  *
  * @author   Mark Taylor
  * @since    23 Nov 2017
- * @see <a href="http://www.ivoa.net/documents/DataLink/">DataLink-1.0</a>
+ * @see <a href="http://www.ivoa.net/documents/DataLink/">DataLink</a>
  */
 public class DatalinkValidator {
 
     private final Reporter reporter_;
+    private final DatalinkVersion version_;
 
     /** DataLink-1.0 sec 3.1. */
     private static final String CANONICAL_DL_CTYPE =
@@ -64,37 +72,27 @@ public class DatalinkValidator {
                        + "(:.*)?" );
 
     /** DataLink 1.0 sec 3.2.6. */
-    private static final String DATALINK_CORE_URI =
-        "http://www.ivoa.net/rdf/datalink/core";
+    private static final VocabChecker SEMANTICS_CHECKER =
+        VocabChecker.DATALINK_CORE;
 
-    /** Content of http://www.ivoa.net/rdf/datalink/core/2014-10-30/. */
-    private static final Collection<String> DATALINK_CORE_PREDICATES =
-            Arrays.asList( new String[] {
-        "this",
-        "progenitor",
-        "derivation",
-        "auxiliary",
-        "weight",
-        "error",
-        "noise",
-        "calibration",
-        "bias",
-        "dark",
-        "flat",
-        "preview",
-        "preview-image",
-        "preview-plot",
-        "proc",
-        "cutout",
-    } );
+    /** DataLink 1.1 sec 3.2.9. */
+    private static final VocabChecker CONTENTQUALIFIER_CHECKER =
+        VocabChecker.PRODUCT_TYPE;
+
+    /** DataLink 1.1 sec 2.2. */
+    private static final Ivoid LINKS_ID =
+        new Ivoid( "ivo://ivoa.net/std/DataLink#links-1.0" );
 
     /**
      * Constructor.
      *
      * @param  reporter  destination for validation methods
+     * @param  version   fixed datalink version to validate against;
+     *                   may be null if not known/specified
      */
-    public DatalinkValidator( Reporter reporter ) {
+    public DatalinkValidator( Reporter reporter, DatalinkVersion version ) {
         reporter_ = reporter;
+        version_ = version;
     }
 
     /**
@@ -124,9 +122,7 @@ public class DatalinkValidator {
         URLConnection conn;
         int httpCode;
         try {
-            conn = url.openConnection();
-            conn = URLUtils.followRedirects( conn, null );
-            conn.connect();
+            conn = AuthManager.getInstance().connect( url );
             httpCode = conn instanceof HttpURLConnection
                      ? ((HttpURLConnection) conn).getResponseCode()
                      : -1;
@@ -203,14 +199,17 @@ public class DatalinkValidator {
             return;
         }
 
+        /* See what version we should be validating against. */
+        DatalinkVersion version = getEffectiveVersion( vodoc );
+
         /* If it was a VOTable, check the content-type. */
         if ( hconn != null ) {
             checkVOTableContentType( hconn.getContentType(), url,
-                                     isLinksService );
+                                     isLinksService, version );
         }
 
         /* Perform the DataLink-specific validation on the VOTable DOM. */
-        validateDatalink( vodoc );
+        validateDatalink( vodoc, version );
     }
 
     /**
@@ -245,7 +244,8 @@ public class DatalinkValidator {
             reporter_.report( DatalinkCode.E_VTSX, msg );
             return;
         }
-        validateDatalink( vodoc );
+        DatalinkVersion version = getEffectiveVersion( vodoc );
+        validateDatalink( vodoc, version );
     }
 
     /**
@@ -253,11 +253,12 @@ public class DatalinkValidator {
      *
      * @param  vodoc  DOM assumed to contain a document conforming to
      *                the DataLink standard
+     * @param  version  datalink version, not null
      */
-    public void validateDatalink( VODocument vodoc ) {
-        LinksDoc linksDoc = createLinksDoc( vodoc );
+    public void validateDatalink( VODocument vodoc, DatalinkVersion version ) {
+        LinksDoc linksDoc = createLinksDoc( vodoc, version );
         if ( linksDoc != null ) {
-            validateLinksDoc( linksDoc );
+            validateLinksDoc( linksDoc, version );
         }
     }
 
@@ -267,8 +268,9 @@ public class DatalinkValidator {
      * already been parsed as a DataLink document.
      *
      * @param  linksDoc  object representing DataLink document
+     * @param  version   datalink specification version, not null
      */
-    public void validateLinksDoc( LinksDoc linksDoc ) {
+    public void validateLinksDoc( LinksDoc linksDoc, DatalinkVersion version ) {
 
         /* Prepare service invokers for the ServiceDescriptors defined
          * by the links doc. */
@@ -277,7 +279,7 @@ public class DatalinkValidator {
 
         /* Check the content of each row in the results table. */
         try {
-            attemptValidateLinksDocRows( linksDoc, invokerMap );
+            attemptValidateLinksDocRows( linksDoc, invokerMap, version );
         }
         catch ( IOException e ) {
 
@@ -296,9 +298,11 @@ public class DatalinkValidator {
      * validation issues as it does.
      *
      * @param  vodoc   DOM assumed to conform to DataLink rules
+     * @param  version   datalink version
      * @return  parsed represntation of the DataLink document
      */
-    public LinksDoc createLinksDoc( VODocument vodoc ) {
+    public LinksDoc createLinksDoc( VODocument vodoc,
+                                    DatalinkVersion version ) {
 
         /* Extract RESOURCE elements by the value of the @type attribute. */
         Map<String,List<VOElement>> resourceMap = getTypedResources( vodoc );
@@ -319,8 +323,8 @@ public class DatalinkValidator {
             reporter_.report( DatalinkCode.E_URES, msg );
             return null;
         }
-        NodeList tableEls = resultsResources.get( 0 )
-                           .getElementsByVOTagName( "TABLE" );
+        VOElement resultsResource = resultsResources.get( 0 );
+        NodeList tableEls = resultsResource.getElementsByVOTagName( "TABLE" );
         int ntab = tableEls.getLength();
         if ( ntab != 1 ) {
             String msg = new StringBuffer()
@@ -336,6 +340,42 @@ public class DatalinkValidator {
             return null;
         }
 
+        /* Check for standardID INFO if applicable (Datalink 1.1 sec 3.3.1). */
+        if ( version.is11() ) {
+            List<String> stdids = new ArrayList<>();
+            NodeList infos = resultsResource.getElementsByVOTagName( "INFO" );
+            boolean hasDlid = false;
+            for ( int ii = 0; ii < infos.getLength(); ii++ ) {
+                Node info = infos.item( ii );
+                if ( info instanceof Element ) {
+                    Element infoEl = (Element) info;
+                    if ( "standardID".equals( infoEl.getAttribute( "name" ) )) {
+                        String stdId = infoEl.getAttribute( "value" );
+                        if ( LINKS_ID.equalsIvoid( new Ivoid( stdId ) ) ) {
+                            hasDlid = true;
+                        }
+                        stdids.add( stdId );
+                    }
+                }
+            }
+            if ( ! hasDlid ) {
+                StringBuffer sbuf = new StringBuffer()
+                   .append( "No DataLink standard identifier; " )
+                   .append( "<INFO name=\"standardID\" " )
+                   .append( "value=\"" )
+                   .append( LINKS_ID )
+                   .append( "\">" )
+                   .append( " should appear in results RESOURCE" );
+                if ( stdids.size() > 0 ) {
+                    sbuf.append( ". These standardIDs do appear: " )
+                        .append( stdids.stream()
+                                       .map( s -> '"' + s + '"' )
+                                       .collect( Collectors.joining( ", " ) ) );
+                }
+                reporter_.report( DatalinkCode.E_DSTD, sbuf.toString() );
+            }
+        }
+
         /* Turn it into a StarTable. */
         TableElement tableEl = (TableElement) tableEls.item( 0 );
         VOStarTable resultTable;
@@ -391,25 +431,55 @@ public class DatalinkValidator {
         }
         ServiceDescriptor[] servDescriptors =
             sdList.toArray( new ServiceDescriptor[ 0 ] );
-        int nIdSd = 0;
-        int nAnonSd = 0;
+        int nSd = servDescriptors.length;
+        int nIdentified = 0;
+        Set<String> nameSet = new HashSet<>();
+        Set<String> descriptionSet = new HashSet<>();
         for ( ServiceDescriptor sd : servDescriptors ) {
-            if ( sd.getDescriptorId() == null ) {
-                nAnonSd++;
+            if ( sd.getDescriptorId() != null ) {
+                nIdentified++;
             }
-            else {
-                nIdSd++;
+            String name = sd.getName();
+            String descrip = sd.getDescription();
+            if ( name != null && name.trim().length() > 0 ) {
+                nameSet.add( name.trim() );
+            }
+            if ( descrip != null && descrip.trim().length() > 0 ) {
+                descriptionSet.add( descrip.trim() );
             }
         }
         String msg = new StringBuffer()
             .append( "Service descriptors defined: " )
-            .append( nIdSd )
+            .append( nIdentified )
             .append( " referenceable, " )
-            .append( nAnonSd )
+            .append( nSd - nIdentified )
             .append( " anonymous" )
             .toString();
         reporter_.report( DatalinkCode.I_SDDF, msg );
 
+        /* Check if they are labelled with name attribute and DESCRIPTION
+         * element as recommended by Datalink 1.1 sec 4.1.
+         * Although this is not part of the Datalink 1.0 specification,
+         * warn even for DL 1.0 validation, since it's still a good idea. */
+        if ( nSd > 1 ) {
+            StringBuffer missBuf = new StringBuffer();
+            if ( nameSet.size() < nSd ) {
+                missBuf.append( "name attributes" );
+            }
+            if ( descriptionSet.size() < nSd ) {
+                missBuf.append( missBuf.length() == 0 ? "" : " and " )
+                       .append( "DESCRIPTION children" );
+            }
+            if ( missBuf.length() > 0 ) {
+                String ndMsg = new StringBuffer()
+                    .append( "Multiple service descriptors defined, " )
+                    .append( "but not all have unique " )
+                    .append( missBuf )
+                    .toString();
+                reporter_.report( DatalinkCode.W_SDND, ndMsg );
+            }
+        }
+
         /* Assemble and return a parsed LinksDoc object. */
         return LinksDoc.createLinksDoc( resultTable, colMap, servDescriptors );
     }
@@ -441,6 +511,39 @@ public class DatalinkValidator {
         return vodoc;
     }
 
+    /**
+     * Returns the DataLink version against which the given document
+     * should be validated.  The choice is reported.
+     *
+     * @param  vodoc  document to validate
+     * @return   validation version, not null
+     */
+    private DatalinkVersion getEffectiveVersion( VODocument vodoc ) {
+
+        /* In principle the document might report its own version.
+         * At time of writing however (PR-DataLink-1.1-20230413)
+         * it can't actually do that, so ignore the vodoc argument. */
+        final DatalinkVersion version;
+        final String vtype;
+        if ( version_ != null ) {
+            version = version_;
+            vtype = "requested";
+        }
+        else {
+            version = DatalinkVersion.V11;
+            vtype = "assumed";
+        }
+        String msg = new StringBuffer()
+           .append( "Using " )
+           .append( vtype )
+           .append( " DataLink version " )
+           .append( version )
+           .append( " for validation" )
+           .toString();
+        reporter_.report( DatalinkCode.I_DLVR, msg );
+        return version;
+    }
+
     /**
      * Identifies the DataLink-defined columns in a table, and reports on
      * any validation issues.
@@ -463,53 +566,64 @@ public class DatalinkValidator {
             /* See if it's a DataLink column. */
             LinkColMap.ColDef<?> coldef = LinkColMap.COLDEF_MAP.get( name );
             if ( coldef != null ) {
+                String stdUcd = coldef.getUcd();
 
                 /* Check UCD against DataLink specification. */
                 String ucd = info.getUCD();
                 if ( ucd == null ) {
-                    String msg = new StringBuffer()
-                        .append( "Missing UCD for column " )
-                        .append( name )
-                        .append( "; should be " )
-                        .append( coldef.getUcd() )
-                        .toString();
-                    reporter_.report( DatalinkCode.E_RUCD, msg );
+                    if ( stdUcd != null ) {
+                        String msg = new StringBuffer()
+                            .append( "Missing UCD for column " )
+                            .append( name )
+                            .append( "; should be " )
+                            .append( stdUcd )
+                            .toString();
+                        reporter_.report( DatalinkCode.E_RUCD, msg );
+                    }
                 }
-                else if ( ! ucd.equals( coldef.getUcd() ) ) {
+                else if ( ! ucd.equals( stdUcd ) ) {
                     String msg = new StringBuffer()
                         .append( "Wrong UCD for column " )
                         .append( name )
                         .append( "; " )
                         .append( ucd )
                         .append( " != " )
-                        .append( coldef.getUcd() )
+                        .append( stdUcd )
                         .toString();
                     reporter_.report( DatalinkCode.E_RUCD, msg );
                 }
 
-                /* Check datatype and units against DataLink specification. */
+                /* Check datatype against DataLink specification. */
                 Class<?> clazz = info.getContentClass();
+                final Class<?> reqClazz;
+                if ( coldef == LinkColMap.COL_CONTENTLENGTH ) {
+                    reqClazz = Long.class;
+                }
+                else {
+                    reqClazz = coldef.getContentClass();
+                }
+                if ( ! reqClazz.isAssignableFrom( clazz ) ) {
+                    String datatype =
+                        info.getAuxDatumValue( VOStarTable.DATATYPE_INFO,
+                                               String.class );
+                    String msg = new StringBuffer()
+                       .append( "Wrong datatype '" )
+                       .append( datatype )
+                       .append( "' for column " )
+                       .append( name )
+                       .append( ", should be " )
+                       .append( reqClazz.getSimpleName().toLowerCase() )
+                       .toString();
+                    reporter_.report( DatalinkCode.E_RTYP, msg );
+                }
 
-                /* Use special knowledge: content_length has
-                 * datatype="long" and units="byte". */
+                /* Only content_length has units ("byte"). */
                 if ( LinkColMap.COL_CONTENTLENGTH == coldef ) {
-                    if ( ! Long.class.equals( clazz ) ) {
-                        String datatype =
-                            info.getAuxDatumValue( VOStarTable.DATATYPE_INFO,
-                                                   String.class );
-                        String msg = new StringBuffer()
-                            .append( "Wrong datatype '" )
-                            .append( datatype )
-                            .append( clazz.isArray() ? " array" : "" )
-                            .append( "' for column " )
-                            .append( name )
-                            .append( ", should be 'long'" )
-                            .toString();
-                        reporter_.report( DatalinkCode.E_RTYP, msg );
-                    }
                     if ( ! "byte".equals( info.getUnitString() ) ) {
                         String msg = new StringBuffer()
-                            .append( "Wrong units for column " )
+                            .append( "Wrong units (" )
+                            .append( info.getUnitString() )
+                            .append( ") for column " )
                             .append( name )
                             .append( " - should be 'byte'" )
                             .toString();
@@ -517,19 +631,6 @@ public class DatalinkValidator {
                     }
                 }
 
-                /* All the others are unit-less strings. */
-                else {
-                    if ( ! String.class.equals( clazz ) ) {
-                        String msg = new StringBuffer()
-                            .append( "Column " )
-                            .append( name )
-                            .append( " should be string, not " )
-                            .append( clazz.getSimpleName() )
-                            .toString();
-                        reporter_.report( DatalinkCode.E_RTYP, msg );
-                    }
-                }
-
                 /* If we haven't already seen this one, and as long as it's
                  * got the right data type, store it for use in the map. */
                 if ( icolMap.containsKey( coldef ) ) {
@@ -553,7 +654,7 @@ public class DatalinkValidator {
         }
         StringBuffer missingBuf = new StringBuffer();
         for ( LinkColMap.ColDef<?> coldef : LinkColMap.COLDEF_MAP.values() ) {
-            if ( ! icolMap.containsKey( coldef ) ) {
+            if ( coldef.isRequired() && ! icolMap.containsKey( coldef ) ) {
                 if ( missingBuf.length() > 0 ) {
                     missingBuf.append( ", " );
                 }
@@ -633,6 +734,7 @@ public class DatalinkValidator {
         paramCounts.put( "accessURL", new Integer( 0 ) );
         paramCounts.put( "standardID", new Integer( 0 ) );
         paramCounts.put( "resourceIdentifier", new Integer( 0 ) );
+        paramCounts.put( "contentType", new Integer( 0 ) );
         for ( VOElement pEl : resourceEl.getChildrenByName( "PARAM" ) ) {
             ParamElement paramEl = (ParamElement) pEl;
             String name = paramEl.getName();
@@ -830,6 +932,23 @@ public class DatalinkValidator {
                 // try to check it??
             }
 
+            /* Check ContentType if present. */
+            String contentType = sd.getContentType();
+            if ( contentType != null ) {
+                ContentType mimeType =
+                    ContentType.parseContentType( contentType );
+                if ( mimeType == null ) {
+                    String msg = new StringBuffer()
+                        .append( "Bad MIME type syntax for contentType PARAM " )
+                        .append( "in service descriptor " )
+                        .append( sdName )
+                        .append( ": " )
+                        .append( contentType )
+                        .toString();
+                    reporter_.report( DatalinkCode.E_DRCT, msg );
+                }
+            }
+
             /* Look at all the input parameters. */
             for ( ServiceParam sp : sd.getInputParams() ) {
 
@@ -890,14 +1009,18 @@ public class DatalinkValidator {
      * @param  invokerMap  map with an entry for each service descriptor;
      *                     key is descriptor ID, and value is ServiceInvoker
      *                     if one could be built, or null otherwise
+     * @param  version   version of DataLink standard, not null
      * @throws  IOException   if there is a read error on the table
      */
     private void
             attemptValidateLinksDocRows( LinksDoc linksDoc,
-                                         Map<String,ServiceInvoker> invokerMap )
+                                         Map<String,ServiceInvoker> invokerMap,
+                                         DatalinkVersion version )
             throws IOException {
         LinkColMap colMap = linksDoc.getColumnMap();
         Map<ServiceParam,String> noParams = new HashMap<ServiceParam,String>();
+        Set<String> idSet = new HashSet<>();
+        String lastId = null;
 
         /* Check requirements for each row. */
         int jrow = 0;
@@ -912,6 +1035,20 @@ public class DatalinkValidator {
                 reporter_.report( DatalinkCode.E_DRID,
                                   "Missing ID for row " + jrow );
             }
+            else {
+                if ( version.is11() ) {
+                    if ( ! id.equals( lastId ) && idSet.contains( id ) ) {
+                        String msg = new StringBuffer()
+                           .append( "Non-contiguous results for ID \"" )
+                           .append( id )
+                           .append( "\" in output" )
+                           .toString();
+                        reporter_.report( DatalinkCode.E_IDSQ, msg );
+                    }
+                    idSet.add( id );
+                    lastId = id;
+                }
+            }
 
             /* Check there is exactly one of access_url, service_def and
              * error_message columns. */
@@ -1027,24 +1164,12 @@ public class DatalinkValidator {
                                   "Null semantics entry for row " + jrow );
             }
             else if ( semantics.startsWith( "#" ) ||
-                      semantics.startsWith( DATALINK_CORE_URI + "#" ) ) {
+                      semantics.startsWith( SEMANTICS_CHECKER
+                                           .getVocabularyUri() + "#" ) ) {
                 String frag =
                     semantics.substring( semantics.indexOf( '#' ) + 1 );
-
-                /* Note this is using a hard-coded list of the core datalink
-                 * semantics predicates.  I think that should be static,
-                 * but if not then I should be pulling RDF from the
-                 * relevant URL and parsing it to get a list of 
-                 * predicates instead. */
-                if ( ! DATALINK_CORE_PREDICATES.contains( frag ) ) {
-                    String msg = new StringBuffer()
-                        .append( "Unknown predicate '" )
-                        .append( frag )
-                        .append( "' from core DataLink vocabulary at row " )
-                        .append( jrow )
-                        .toString();
-                    reporter_.report( DatalinkCode.E_SMCO, msg );
-                }
+                checkVocab( SEMANTICS_CHECKER, frag, "semantics", jrow,
+                            DatalinkCode.W_SMCO, DatalinkCode.E_SMCO );
             }
             else {
                 String msg = new StringBuffer()
@@ -1084,12 +1209,97 @@ public class DatalinkValidator {
                     reporter_.report( DatalinkCode.W_DRCT, msg );
                 }
             }
+
+            /* Check content_qualifier column. */
+            if ( version.is11() ) {
+                String cqual = colMap.getContentQualifier( row );
+                if ( cqual == null ) {
+                    // no problem, it's optional
+                }
+                else if ( cqual.startsWith( "#" ) ||
+                          cqual.startsWith( CONTENTQUALIFIER_CHECKER
+                                           .getVocabularyUri() + "#" ) ) {
+                    String frag = cqual.substring( cqual.indexOf( '#' ) + 1 );
+                    checkVocab( CONTENTQUALIFIER_CHECKER, frag,
+                                "content_qualifier", jrow,
+                                DatalinkCode.W_CQCO, DatalinkCode.E_CQCO );
+                }
+                else {
+                    String msg = new StringBuffer()
+                       .append( "Content qualifier from" )
+                       .append( " non-standard vocabulary" )
+                       .append( " at row " )
+                       .append( jrow )
+                       .append( ": " )
+                       .append( cqual )
+                       .toString();
+                    reporter_.report( DatalinkCode.I_CQCU, msg );
+                }
+            }
+
+            /* Check link_auth column. */
+            if ( version.is11() ) {
+                String linkAuth = colMap.getLinkAuth( row );
+                if ( linkAuth != null &&
+                     ! "false".equals( linkAuth ) &&
+                     ! "true".equals( linkAuth ) &&
+                     ! "optional".equals( linkAuth ) ) {
+                    String msg = new StringBuffer()
+                       .append( "Bad link_auth value \"" )
+                       .append( linkAuth )
+                       .append( "\", should be " )
+                       .append( "\"false\", \"true\", \"optional\"" )
+                       .append( " or null" )
+                       .toString();
+                    reporter_.report( DatalinkCode.E_LKAZ, msg );
+                }
+            }
         }
         rseq.close();
         reporter_.report( DatalinkCode.I_DLNR,
                           "Datalink table rows checked: " + jrow );
     }
 
+    /**
+     * Checks a string against terms in a VO Vocabulary, and issues
+     * validation reports as appropriate.
+     *
+     * @param  checker  defines the vocabulary to check against
+     * @param  term    term to check
+     * @param  colName  name of datalink column in which term appears
+     * @param  jrow    1-based index of row in which term appears
+     * @param  warnCode  reporting code for deprecated/prelminary warnings
+     * @param  errCode  reporting code for unknown terms
+     */
+    private void checkVocab( VocabChecker checker, String term,
+                             final String colName, final int jrow,
+                             DatalinkCode warnCode, DatalinkCode errCode ) {
+        checker.checkTerm( term, new VocabChecker.TermReporter() {
+            public void termFound() {
+            }
+            public void termPreliminary( String msg ) {
+                reporter_.report( warnCode, message( "Preliminary", msg ) );
+            }
+            public void termDeprecated( String msg ) {
+                reporter_.report( warnCode, message( "Deprecated", msg ) );
+            }
+            public void termUnknown( String msg ) {
+                reporter_.report( errCode, message( "Unknown", msg ) );
+            }
+            private String message( String type, String msg ) {
+                return new StringBuffer()
+                      .append( type )
+                      .append( ' ' )
+                      .append( colName )
+                      .append( " term at row " )
+                      .append( jrow )
+                      .append( ": " )
+                      .append( msg )
+                      .toString();
+            }
+        } );
+    }
+
     /**
      * Performs validation checks on an input stream that is supposed to
      * contain a DALI/DataLink VOTable error document.
@@ -1133,7 +1343,7 @@ public class DatalinkValidator {
 
         /* If it was a VOTable, check the content-type and
          * report any validation items. */
-        checkVOTableContentType( contentType, url, false );
+        checkVOTableContentType( contentType, url, false, version_ );
 
         /* Get unique RESOURCE/@type="results" element. */
         Map<String,List<VOElement>> resourceMap = getTypedResources( vodoc );
@@ -1215,15 +1425,18 @@ public class DatalinkValidator {
      * The declaration should report a VOTable document;
      * if the response is asserted to come from a DataLink {links} service,
      * additional constraints are applied to the form of the Content-type.
+     * This is specified by Section 3.3 of DataLink 1.0 and 1.1.
      *
      * @param   ctypeTxt   content-type header value
      * @param   url     URL of input, used for reports
      * @param   isLinksResult  true iff the connection is supposed to be
      *                         the successful result of a
      *                         DataLink {links} service
+     * @param   version   DataLink standard version, or null if not known
      */
     private void checkVOTableContentType( String ctypeTxt, URL url,
-                                          boolean isLinksResult ) {
+                                          boolean isLinksResult,
+                                          DatalinkVersion version ) {
 
         /* Get the content-type header. */
         if ( ctypeTxt == null || ctypeTxt.trim().length() == 0 ) {
@@ -1242,28 +1455,54 @@ public class DatalinkValidator {
         }
         assert ctype != null;
 
-        /* Perform checks on its parsed content. */
-        /* DataLink sec 3.3 puts specific requirements on the form of the
-         * content type. */
+        /* It must in any case identify as a VOTable.
+         * If it doesn't, report that error and bail out. */
+        if ( ! ( ctype.matches( "text", "xml" ) ||
+                 ctype.matches( "application", "x-votable+xml" ) ) ) {
+            String msg = new StringBuilder()
+               .append( "Bad content type " )
+               .append( ctype )
+               .append( " for HTTP response which should contain " )
+               .append( "VOTable result or error document" )
+               .append( " (" )
+               .append( url )
+               .append( ")" )
+               .toString();
+            reporter_.report( DatalinkCode.E_VTCT, msg );
+        }
+
+        /* If it is the output from a DataLink service, DataLink sec 3.3.
+         * makes some more specific requirements/recommendations. */
         if ( isLinksResult ) {
 
+            /* See if all the datalink identification bits are in place. */
             if ( ! ctype.matches( "application", "x-votable+xml" ) ||
                  ! "datalink".equals( ctype.getParameter( "content" ) ) ) {
                 String msg = new StringBuffer()
-                   .append( "Incorrect Content-Type " )
+                   .append( "Content-Type " )
                    .append( ctypeTxt )
+                   .append( "does not match canonical form " )
+                   .append( CANONICAL_DL_CTYPE )
                    .append( " for DataLink service " )
                    .append( url )
-                   .append( "; should be like " )
-                   .append( CANONICAL_DL_CTYPE )
                    .toString();
-                reporter_.report( DatalinkCode.E_DLCT, msg );
+
+                /* In DL 1.0 this is a requirement, in DL 1.1 it's a
+                 * recommendation.  Default to the less restrictive one
+                 * if we don't have a known version. */
+                DatalinkCode code = version == null || version.is11()
+                                  ? DatalinkCode.W_DLCT
+                                  : DatalinkCode.E_DLCT;
+                reporter_.report( code, msg );
             }
+
+            /* If that one passes make a stronger test: does the content type
+             * have the canonical form. */
             else if ( ! CANONICAL_DL_CTYPE.equals( ctypeTxt ) ) {
                 String msg = new StringBuffer()
                    .append( "Content-Type " )
                    .append( ctypeTxt )
-                   .append( " differs from canonical form " )
+                   .append( " does not exactly match canonical form " )
                    .append( CANONICAL_DL_CTYPE )
                    .append( " for DataLink service " )
                    .append( url )
@@ -1271,23 +1510,6 @@ public class DatalinkValidator {
                 reporter_.report( DatalinkCode.W_DLCT, msg );
             }
         }
-
-        /* Otherwise, just check it declares as a VOTable. */
-        else {
-            if ( ! ( ctype.matches( "text", "xml" ) ||
-                     ctype.matches( "application", "x-votable+xml" ) ) ) {
-                String msg = new StringBuilder()
-                   .append( "Bad content type " )
-                   .append( ctype )
-                   .append( " for HTTP response which should contain " )
-                   .append( "VOTable result or error document" )
-                   .append( " (" )
-                   .append( url )
-                   .append( ")" )
-                   .toString();
-                reporter_.report( DatalinkCode.E_VTCT, msg );
-            }
-        }
     }
 
     /**
