@@ -22,6 +22,7 @@ import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.ttools.func.Times;
 import uk.ac.starlink.ttools.votlint.VocabChecker;
 import uk.ac.starlink.vo.ColumnMeta;
+import uk.ac.starlink.vo.Ivoid;
 import uk.ac.starlink.vo.SchemaMeta;
 import uk.ac.starlink.vo.TableMeta;
 import uk.ac.starlink.vo.TapQuery;
@@ -46,12 +47,12 @@ public class EpnTapStage implements Stage {
     public static final String EPNCORE_TNAME = "epn_core";
 
     /** Required utype of EPN-TAP tables. */
-    public static final String EPNCORE_UTYPE =
-        "ivo://ivoa.net/std/epntap#table-2.0";
+    public static final Ivoid EPNCORE_UTYPE =
+        new Ivoid( "ivo://ivoa.net/std/epntap#table-2.0" );
 
     /** Transitional utype of EPN-TAP tables. */
-    public static final String EPNCORE_UTYPE2 =
-        "ivo://vopdc.obspm/std/epncore#schema-2.0";
+    public static final Ivoid EPNCORE_UTYPE2 =
+        new Ivoid( "ivo://vopdc.obspm/std/epncore#schema-2.0" );
 
     // Julian Day times that bound believable values.
     // Times.mjdToDecYear(jd-2400000.5).
@@ -65,13 +66,7 @@ public class EpnTapStage implements Stage {
     );
 
     // VocabularyChecker for https://www.ivoa.net/rdf/messenger.
-    // Note at time of writing these are all marked Preliminary.
-    private static final VocabChecker MESSENGER_VOCAB =
-        new VocabChecker( "http://www.ivoa.net/rdf/messenger",
-                          new String[] {
-                              "EUV", "Gamma-ray", "Infrared", "Millimeter",
-                              "Neutrino", "Optical", "Photon", "UV", "X-ray",
-                          } );
+    private static final VocabChecker MESSENGER_VOCAB = VocabChecker.MESSENGER;
 
     /**
      * Constructor.
@@ -95,11 +90,11 @@ public class EpnTapStage implements Stage {
         for ( SchemaMeta smeta : metaHolder_.getTableMetadata() ) {
             for ( TableMeta tmeta : smeta.getTables() ) {
                 String tname = tmeta.getName();
-                String utype = tmeta.getUtype();
+                Ivoid utype = new Ivoid( tmeta.getUtype() );
                 String subname = tname.replaceAll( "^.*[.]", "" );
                 boolean isEpnName = EPNCORE_TNAME.equalsIgnoreCase( subname );
-                boolean isEpnUtype = EPNCORE_UTYPE.equalsIgnoreCase( utype );
-                boolean isEpnUtype2 = EPNCORE_UTYPE2.equalsIgnoreCase( utype );
+                boolean isEpnUtype = EPNCORE_UTYPE.equalsIvoid( utype );
+                boolean isEpnUtype2 = EPNCORE_UTYPE2.equalsIvoid( utype );
                 if ( isEpnName && ! isEpnUtype ) {
                     final String msg;
                     final ReportCode code;
@@ -563,9 +558,10 @@ public class EpnTapStage implements Stage {
                            .append( cname )
                            .append( " in table " )
                            .append( tname_ )
-                           .append( " has unit \"" )
-                           .append( gotUnit )
-                           .append( "\"; for spatial_frame_type \"" )
+                           .append( gotUnit == null
+                                        ? " has no unit"
+                                        : " has unit \"" + gotUnit + "\"" )
+                           .append( "; for spatial_frame_type \"" )
                            .append( ftype.toString().toLowerCase() )
                            .append( "\" recommended unit is \"" )
                            .append( stdUnit )
@@ -580,15 +576,17 @@ public class EpnTapStage implements Stage {
                                                    : toMinUcd( u ) )
                                   .map( String::toLowerCase )
                                   .collect( Collectors.toList() );
-                        if ( ! mmStdUcds.contains( gotUcd.toLowerCase() ) ) {
+                        if ( gotUcd == null ||
+                             ! mmStdUcds.contains( gotUcd.toLowerCase() ) ) {
                             StringBuffer mbuf = new StringBuffer()
                                .append( "Coordinate UCD mismatch: " )
                                .append( cname )
                                .append( " in table " )
                                .append( tname_ )
-                               .append( " has UCD \"" )
-                               .append( gotUcd )
-                               .append( "\"; for spatial_frame_type \"" )
+                               .append( gotUcd == null
+                                            ? " has no UCD"
+                                            : " has UCD \"" + gotUcd + "\"" )
+                               .append( "; for spatial_frame_type \"" )
                                .append( ftype.toString().toLowerCase() )
                                .append( "\" recommended UCD" );
                             if ( mmStdUcds.size() == 1 ) {
